@@ -23,16 +23,14 @@
         since FileIo just sits atop of FILE* streams.
 
   File     : iotest.cpp
-  Version  : $Rev: 2045 $
+  Version  : $Rev: 2286 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
   History  : 04-Dec-04, brad: created
  */
 // *****************************************************************************
 // included header files
-#include <exiv2/types.hpp>
-#include <exiv2/error.hpp>
-#include <exiv2/futils.hpp>
-#include <exiv2/basicio.hpp>
+#include <exiv2/exiv2.hpp>
+
 #include <cstdio>                               // for EOF
 #include <cstring>
 #include <iostream>
