@@ -20,14 +20,14 @@
  */
 /*
   File:      actions.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2374 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
              30-Apr-06, Roger Larsson: Print filename if processing multiple files
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: actions.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: actions.cpp 2374 2010-11-06 13:53:15Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -41,7 +41,7 @@ EXIV2_RCSID("@(#) $Id: actions.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
 # include "timegm.h"
 #endif
 #include "actions.hpp"
-#include "exiv2.hpp"
+#include "exiv2app.hpp"
 #include "image.hpp"
 #include "jpgimage.hpp"
 #include "xmpsidecar.hpp"
@@ -49,7 +49,6 @@ EXIV2_RCSID("@(#) $Id: actions.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
 #include "types.hpp"
 #include "exif.hpp"
 #include "easyaccess.hpp"
-#include "canonmn.hpp"
 #include "iptc.hpp"
 #include "xmp.hpp"
 #include "preview.hpp"
@@ -482,11 +481,10 @@ namespace Action {
 
     int Print::printList()
     {
-        int rc = 0;
         if (!Exiv2::fileExists(path_, true)) {
             std::cerr << path_
                       << ": " << _("Failed to open the file\n");
-            rc = -1;
+            return -1;
         }
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open(path_);
         assert(image.get() != 0);
@@ -498,71 +496,9 @@ namespace Action {
         if (Params::instance().printItems_ == 0) {
             Params::instance().printItems_ = Params::prKey | Params::prType | Params::prCount | Params::prTrans;
         }
-        if (!Params::instance().keys_.empty()) {
-            for (Params::Keys::const_iterator key = Params::instance().keys_.begin();
-                 key != Params::instance().keys_.end(); ++key) {
-                rc |= grepTag(*key, image.get());
-            }
-        }
-        else {
-            rc = printMetadata(image.get());
-        }
-        return rc;
+        return printMetadata(image.get());
     } // Print::printList
 
-    int Print::grepTag(const std::string& key, const Exiv2::Image* image)
-    {
-        int rc = 0;
-        if (key.empty()) return rc;
-        switch (key[0]) {
-        case 'E':
-            if (Params::instance().printTags_ & Exiv2::mdExif) {
-                Exiv2::ExifKey ek(key);
-                const Exiv2::ExifData& exifData = image->exifData();
-                Exiv2::ExifData::const_iterator md = exifData.findKey(ek);
-                if (md != exifData.end()) printMetadatum(*md, image);
-                if (exifData.empty()) {
-                    if (Params::instance().verbose_) {
-                        std::cerr << path_ << ": " << _("No Exif data found in the file\n");
-                    }
-                    rc = -3;
-                }
-            }
-            break;
-        case 'I':
-            if (Params::instance().printTags_ & Exiv2::mdIptc) {
-                Exiv2::IptcKey ik(key);
-                const Exiv2::IptcData& iptcData = image->iptcData();
-                Exiv2::IptcData::const_iterator md = iptcData.findKey(ik);
-                if (md != iptcData.end()) printMetadatum(*md, image);
-                if (iptcData.empty()) {
-                    if (Params::instance().verbose_) {
-                        std::cerr << path_ << ": " << _("No IPTC data found in the file\n");
-                    }
-                    rc = -3;
-                }
-            }
-            break;
-        case 'X':
-            if (Params::instance().printTags_ & Exiv2::mdXmp) {
-                Exiv2::XmpKey xk(key);
-                const Exiv2::XmpData& xmpData = image->xmpData();
-                Exiv2::XmpData::const_iterator md = xmpData.findKey(xk);
-                if (md != xmpData.end()) printMetadatum(*md, image);
-                if (xmpData.empty()) {
-                    if (Params::instance().verbose_) {
-                        std::cerr << path_ << ": " << _("No XMP data found in the file\n");
-                    }
-                    rc = -3;
-                }
-            }
-            break;
-        default:
-            throw Exiv2::Error(1, std::string(_("Invalid key")) + " `" + key + "'");
-        }
-        return rc;
-    } // Print::grepTag
-
     int Print::printMetadata(const Exiv2::Image* image)
     {
         int rc = 0;
@@ -608,8 +544,20 @@ namespace Action {
         return rc;
     } // Print::printMetadata
 
+    bool Print::grepTag(const std::string& key)
+    {
+        if (Params::instance().keys_.empty()) return true;
+        for (Params::Keys::const_iterator k = Params::instance().keys_.begin();
+             k != Params::instance().keys_.end(); ++k) {
+            if (*k == key) return true;
+        }
+        return false;
+    }
+
     void Print::printMetadatum(const Exiv2::Metadatum& md, const Exiv2::Image* pImage)
     {
+        if (!grepTag(md.key())) return;
+
         if (   Params::instance().unknown_
             && md.tagName().substr(0, 2) == "0x") {
             return;
@@ -1474,7 +1422,7 @@ namespace Action {
             std::cout << _("Reg ") << modifyCmd.key_ << "=\""
                       << modifyCmd.value_ << "\"" << std::endl;
         }
-        // Registration has been done immediately after parsing the command.
+        Exiv2::XmpProperties::registerNs(modifyCmd.value_, modifyCmd.key_);
     }
 
     Modify::AutoPtr Modify::clone() const
