@@ -20,13 +20,13 @@
  */
 /*
   File:      basicio.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2344 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
   History:   04-Dec-04, brad: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: basicio.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: basicio.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -280,6 +280,7 @@ namespace Exiv2 {
             p_->hFile_ = 0;
 #else
             if (p_->isWriteable_) {
+                seek(0, BasicIo::beg);
                 write(p_->pMappedArea_, p_->mappedLength_);
             }
             if (p_->isMalloced_) {
@@ -570,7 +571,7 @@ namespace Exiv2 {
             if (::lstat(pf, &buf1) == -1) {
                 statOk = false;
 #ifndef SUPPRESS_WARNINGS
-                std::cerr << "Warning: " << Error(2, pf, strError(), "::lstat") << "\n";
+                EXV_WARNING << Error(2, pf, strError(), "::lstat") << "\n";
 #endif
             }
             origStMode = buf1.st_mode;
@@ -587,7 +588,7 @@ namespace Exiv2 {
                 if (::stat(pf, &buf1) == -1) {
                     statOk = false;
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: " << Error(2, pf, strError(), "::stat") << "\n";
+                    EXV_WARNING << Error(2, pf, strError(), "::stat") << "\n";
 #endif
                 }
                 origStMode = buf1.st_mode;
@@ -615,14 +616,14 @@ namespace Exiv2 {
                 if (statOk && ::_wstat(wpf, &buf2) == -1) {
                     statOk = false;
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: " << Error(2, wpf, strError(), "::_wstat") << "\n";
+                    EXV_WARNING << Error(2, wpf, strError(), "::_wstat") << "\n";
 #endif
                 }
                 if (statOk && origStMode != buf2.st_mode) {
                     // Set original file permissions
                     if (::_wchmod(wpf, origStMode) == -1) {
 #ifndef SUPPRESS_WARNINGS
-                        std::cerr << "Warning: " << Error(2, wpf, strError(), "::_wchmod") << "\n";
+                        EXV_WARNING << Error(2, wpf, strError(), "::_wchmod") << "\n";
 #endif
                     }
                 }
@@ -642,14 +643,14 @@ namespace Exiv2 {
                 if (statOk && ::stat(pf, &buf2) == -1) {
                     statOk = false;
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: " << Error(2, pf, strError(), "::stat") << "\n";
+                    EXV_WARNING << Error(2, pf, strError(), "::stat") << "\n";
 #endif
                 }
                 if (statOk && origStMode != buf2.st_mode) {
                     // Set original file permissions
                     if (::chmod(pf, origStMode) == -1) {
 #ifndef SUPPRESS_WARNINGS
-                        std::cerr << "Warning: " << Error(2, pf, strError(), "::chmod") << "\n";
+                        EXV_WARNING << Error(2, pf, strError(), "::chmod") << "\n";
 #endif
                     }
                 }
