@@ -21,7 +21,7 @@
 /*!
   @file    crwimage_int.hpp
   @brief   Internal classes to support CRW/CIFF format.
-  @version $Rev: 2045 $
+  @version $Rev: 2331 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    28-Aug-05, ahu: created
@@ -32,6 +32,7 @@
 // *****************************************************************************
 // included header files
 #include "types.hpp"
+#include "tags_int.hpp"
 #include "image.hpp"
 #include "basicio.hpp"
 
@@ -556,7 +557,7 @@ namespace Exiv2 {
             uint16_t      crwDir,
             uint32_t      size,
             uint16_t      tag,
-            IfdId         ifdId,
+            Internal::IfdId ifdId,
             CrwDecodeFct  toExif,
             CrwEncodeFct  fromExif)
             : crwTagId_ (crwTagId),
