@@ -20,14 +20,14 @@
  */
 /*
   File:      datasets.cpp
-  Version:   $Rev: 2109 $
+  Version:   $Rev: 2286 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
              Gilles Caulier (gc) <caulier dot gilles at gmail dot com>
   History:   24-Jul-04, brad: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: datasets.cpp 2109 2010-04-19 13:17:17Z cgilles $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: datasets.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
 
 // *****************************************************************************
 // included header files
