@@ -20,14 +20,14 @@
  */
 /*
   File:      easyaccess.cpp
-  Version:   $Rev: 2214 $
+  Version:   $Rev: 2380 $
   Author(s): Carsten Pfeiffer <pfeiffer@kde.org>
              Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   28-Feb-09, gis: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: easyaccess.cpp 2214 2010-05-09 16:00:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: easyaccess.cpp 2380 2010-11-22 14:46:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -70,7 +70,14 @@ namespace Exiv2 {
             "Exif.Image.Orientation",
             "Exif.Panasonic.Rotation",
             "Exif.MinoltaCs5D.Rotation",
-            "Exif.MinoltaCs7D.Rotation"
+            "Exif.MinoltaCs5D.Rotation2",
+            "Exif.MinoltaCs7D.Rotation",
+            "Exif.Sony1MltCsA100.Rotation",
+            "Exif.Sony1Cs.Rotation",
+            "Exif.Sony2Cs.Rotation",
+            "Exif.Sony1Cs2.Rotation",
+            "Exif.Sony2Cs2.Rotation",
+            "Exif.Sony1MltCsA100.Rotation"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -91,8 +98,14 @@ namespace Exiv2 {
             "Exif.MinoltaCsOld.ISOSetting",
             "Exif.MinoltaCs5D.ISOSpeed",
             "Exif.MinoltaCs7D.ISOSpeed",
+            "Exif.Sony1Cs.ISOSetting",
+            "Exif.Sony2Cs.ISOSetting",
+            "Exif.Sony1Cs2.ISOSetting",
+            "Exif.Sony2Cs2.ISOSetting",
+            "Exif.Sony1MltCsA100.ISOSetting",
             "Exif.Pentax.ISO",
-            "Exif.Olympus.ISOSpeed"
+            "Exif.Olympus.ISOSpeed",
+            "Exif.Samsung2.ISO"
         };
 
         // Find the first ISO value which is not "0"
@@ -119,7 +132,11 @@ namespace Exiv2 {
             "Exif.CanonSi.FlashBias",
             "Exif.Panasonic.FlashBias",
             "Exif.Olympus.FlashBias",
-            "Exif.OlympusCs.FlashExposureComp"
+            "Exif.OlympusCs.FlashExposureComp",
+            "Exif.Minolta.FlashExposureComp",
+            "Exif.SonyMinolta.FlashExposureComp",
+            "Exif.Sony1.FlashExposureComp",
+            "Exif.Sony2.FlashExposureComp"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -134,6 +151,9 @@ namespace Exiv2 {
             "Exif.MinoltaCs5D.ExposureMode",
             "Exif.MinoltaCsNew.ExposureMode",
             "Exif.MinoltaCsOld.ExposureMode",
+            "Exif.Sony1MltCsA100.ExposureMode",
+            "Exif.Sony1Cs.ExposureProgram",
+            "Exif.Sony2Cs.ExposureProgram",
             "Exif.Sigma.ExposureMode"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
@@ -145,10 +165,16 @@ namespace Exiv2 {
             "Exif.CanonCs.EasyMode",
             "Exif.Fujifilm.PictureMode",
             "Exif.MinoltaCsNew.SubjectProgram",
+            "Exif.MinoltaCsOld.SubjectProgram",
+            "Exif.Minolta.SceneMode",
+            "Exif.SonyMinolta.SceneMode",
+            "Exif.Sony1.SceneMode",
+            "Exif.Sony2.SceneMode",
             "Exif.OlympusCs.SceneMode",
             "Exif.Panasonic.ShootingMode",
             "Exif.Panasonic.SceneMode",
-            "Exif.Pentax.PictureMode"
+            "Exif.Pentax.PictureMode",
+            "Exif.Photo.SceneCaptureType"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -162,7 +188,9 @@ namespace Exiv2 {
             "Exif.OlympusCs.MacroMode",
             "Exif.Panasonic.Macro",
             "Exif.MinoltaCsNew.MacroMode",
-            "Exif.MinoltaCsOld.MacroMode"
+            "Exif.MinoltaCsOld.MacroMode",
+            "Exif.Sony1.Macro",
+            "Exif.Sony2.Macro"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -183,7 +211,14 @@ namespace Exiv2 {
             "Exif.MinoltaCsNew.Quality",
             "Exif.MinoltaCsOld.Quality",
             "Exif.MinoltaCs5D.Quality",
-            "Exif.MinoltaCs7D.Quality"
+            "Exif.MinoltaCs7D.Quality",
+            "Exif.Sony1MltCsA100.Quality",
+            "Exif.Sony1.JPEGQuality",
+            "Exif.Sony1.Quality",
+            "Exif.Sony1Cs.Quality",
+            "Exif.Sony2.JPEGQuality",
+            "Exif.Sony2.Quality",
+            "Exif.Sony2Cs.Quality"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -204,6 +239,13 @@ namespace Exiv2 {
             "Exif.MinoltaCs7D.WhiteBalance",
             "Exif.MinoltaCsNew.WhiteBalance",
             "Exif.MinoltaCsOld.WhiteBalance",
+            "Exif.Minolta.WhiteBalance",
+            "Exif.Sony1MltCsA100.WhiteBalance",
+            "Exif.SonyMinolta.WhiteBalance",
+            "Exif.Sony1.WhiteBalance",
+            "Exif.Sony2.WhiteBalance",
+            "Exif.Sony1.WhiteBalance2",
+            "Exif.Sony2.WhiteBalance2",
             "Exif.Photo.WhiteBalance"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
@@ -216,8 +258,12 @@ namespace Exiv2 {
             "Exif.NikonLd1.LensIDNumber",
             "Exif.NikonLd2.LensIDNumber",
             "Exif.NikonLd3.LensIDNumber",
+            "Exif.Pentax.LensType",
             "Exif.Minolta.LensID",
-            "Exif.Pentax.LensType"
+            "Exif.SonyMinolta.LensID",
+            "Exif.Sony1.LensID",
+            "Exif.Sony2.LensID",
+            "Exif.Samsung2.LensType"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -290,7 +336,8 @@ namespace Exiv2 {
         static const char* keys[] = {
             "Exif.Photo.MeteringMode",
             "Exif.Image.MeteringMode",
-            "Exif.CanonCs.MeteringMode"
+            "Exif.CanonCs.MeteringMode",
+            "Exif.Sony1MltCsA100.MeteringMode"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -315,7 +362,8 @@ namespace Exiv2 {
     {
         static const char* keys[] = {
             "Exif.Photo.ExposureTime",
-            "Exif.Image.ExposureTime"
+            "Exif.Image.ExposureTime",
+            "Exif.Samsung2.ExposureTime"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -324,7 +372,8 @@ namespace Exiv2 {
     {
         static const char* keys[] = {
             "Exif.Photo.FNumber",
-            "Exif.Image.FNumber"
+            "Exif.Image.FNumber",
+            "Exif.Samsung2.FNumber"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
@@ -354,7 +403,7 @@ namespace Exiv2 {
             "Exif.Nikon3.SerialNumber",
             "Exif.Nikon3.SerialNO",
             "Exif.Fujifilm.SerialNumber",
-            "Exif.Olympus.SerialNumber",
+            "Exif.Olympus.SerialNumber2",
             "Exif.Sigma.SerialNumber"
         };
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
@@ -374,4 +423,29 @@ namespace Exiv2 {
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
 
+    ExifData::const_iterator afPoint(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.CanonPi.AFPointsUsed",
+            "Exif.CanonPi.AFPointsUsed20D",
+            "Exif.CanonSi.AFPointUsed",
+            "Exif.CanonCs.AFPoint",
+            "Exif.MinoltaCs7D.AFPoints",
+            "Exif.Nikon1.AFFocusPos",
+            "Exif.NikonAf.AFPoint",
+            "Exif.NikonAf.AFPointsInFocus",
+            "Exif.NikonAf2.AFPointsUsed",
+            "Exif.NikonAf2.PrimaryAFPoint",
+            "Exif.OlympusFi.AFPoint",
+            "Exif.Pentax.AFPoint",
+            "Exif.Pentax.AFPointInFocus",
+            "Exif.Sony1Cs.LocalAFAreaPoint",
+            "Exif.Sony2Cs.LocalAFAreaPoint",
+            "Exif.Sony1Cs2.LocalAFAreaPoint",
+            "Exif.Sony2Cs2.LocalAFAreaPoint",
+            "Exif.Sony1MltCsA100.LocalAFAreaPoint"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
 }                                       // namespace Exiv2
