@@ -21,7 +21,7 @@
 /*!
   @file    easyaccess.hpp
   @brief   Provides easy (high-level) access to some Exif meta data.
-  @version $Rev: 2214 $
+  @version $Rev: 2380 $
   @author  Carsten Pfeiffer <pfeiffer@kde.org>
   @date    28-Feb-09, gis: created
  */
@@ -78,8 +78,10 @@ namespace Exiv2 {
     EXIV2API ExifData::const_iterator subjectDistance(const ExifData& ed);
     //! Return the camera serial number
     EXIV2API ExifData::const_iterator serialNumber(const ExifData& ed);
-    //! Return the focal lenght setting
+    //! Return the focal length setting
     EXIV2API ExifData::const_iterator focalLength(const ExifData& ed);
+    //! Return the AF point
+    EXIV2API ExifData::const_iterator afPoint(const ExifData& ed);
 
 } // namespace Exiv2
 
