@@ -20,13 +20,13 @@
  */
 /*
   File:      error.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2353 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   02-Apr-05, ahu: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: error.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: error.cpp 2353 2010-09-21 15:45:07Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -34,7 +34,9 @@ EXIV2_RCSID("@(#) $Id: error.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
 #include "i18n.h"                // NLS support.
 
 // + standard includes
+#include <iostream>
 #include <string>
+#include <cassert>
 
 // *****************************************************************************
 namespace {
@@ -111,6 +113,21 @@ namespace {
 // class member definitions
 namespace Exiv2 {
 
+    LogMsg::Level LogMsg::level_ = LogMsg::info; // Default output level
+    LogMsg::Handler LogMsg::handler_ = LogMsg::defaultHandler;
+
+    void LogMsg::defaultHandler(int level, const char* s)
+    {
+        switch (static_cast<LogMsg::Level>(level)) {
+        case LogMsg::debug: std::cerr << "Debug: "; break;
+        case LogMsg::info:  break;
+        case LogMsg::warn:  std::cerr << "Warning: "; break;
+        case LogMsg::error: std::cerr << "Error: "; break;
+        case LogMsg::mute:  assert(false);
+        }
+        std::cerr << s;
+    }
+
     AnyError::~AnyError() throw()
     {
     }
