@@ -20,14 +20,14 @@
  */
 /*
   File:      exif.cpp
-  Version:   $Rev: 2239 $
+  Version:   $Rev: 2353 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: exif.cpp 2239 2010-05-25 14:53:56Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: exif.cpp 2353 2010-09-21 15:45:07Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -40,6 +40,7 @@ EXIV2_RCSID("@(#) $Id: exif.cpp 2239 2010-05-25 14:53:56Z ahuggel $")
 #include "exif.hpp"
 #include "metadatum.hpp"
 #include "tags.hpp"
+#include "tags_int.hpp"
 #include "value.hpp"
 #include "types.hpp"
 #include "error.hpp"
@@ -180,7 +181,7 @@ namespace {
     long sumToLong(const Exiv2::Exifdatum& md);
 
     //! Helper function to delete all tags of a specific IFD from the metadata.
-    void eraseIfd(Exiv2::ExifData& ed, Exiv2::IfdId ifdId);
+    void eraseIfd(Exiv2::ExifData& ed, Exiv2::Internal::IfdId ifdId);
 
 }
 
@@ -227,7 +228,11 @@ namespace Exiv2 {
 
     std::ostream& Exifdatum::write(std::ostream& os, const ExifData* pMetadata) const
     {
-        return ExifTags::printTag(os, tag(), ifdId(), value(), pMetadata);
+        if (value().count() == 0) return os;
+        PrintFct fct = printValue;
+        const TagInfo* ti = Internal::tagInfo(tag(), static_cast<IfdId>(ifdId()));
+        if (ti != 0) fct = ti->printFct_;
+        return fct(os, value(), pMetadata);
     }
 
     const Value& Exifdatum::value() const
@@ -301,7 +306,7 @@ namespace Exiv2 {
     int Exifdatum::setValue(const std::string& value)
     {
         if (value_.get() == 0) {
-            TypeId type = ExifTags::tagType(tag(), ifdId());
+            TypeId type = key_->defaultTypeId();
             value_ = Value::create(type);
         }
         return value_->read(value);
@@ -342,19 +347,14 @@ namespace Exiv2 {
         return key_.get() == 0 ? 0xffff : key_->tag();
     }
 
-    IfdId Exifdatum::ifdId() const
+    int Exifdatum::ifdId() const
     {
         return key_.get() == 0 ? ifdIdNotSet : key_->ifdId();
     }
 
     const char* Exifdatum::ifdName() const
     {
-        return key_.get() == 0 ? "" : key_->ifdName();
-    }
-
-    std::string Exifdatum::ifdItem() const
-    {
-        return key_.get() == 0 ? "" : key_->ifdItem();
+        return key_.get() == 0 ? "" : Internal::ifdName(static_cast<Internal::IfdId>(key_->ifdId()));
     }
 
     int Exifdatum::idx() const
@@ -634,10 +634,10 @@ namespace Exiv2 {
                                           size);
 #ifndef SUPPRESS_WARNINGS
         if (!iptcData.empty()) {
-            std::cerr << "Warning: Ignoring IPTC information encoded in the Exif data.\n";
+            EXV_WARNING << "Ignoring IPTC information encoded in the Exif data.\n";
         }
         if (!xmpData.empty()) {
-            std::cerr << "Warning: Ignoring XMP information encoded in the Exif data.\n";
+            EXV_WARNING << "Ignoring XMP information encoded in the Exif data.\n";
         }
 #endif
         return bo;
@@ -693,7 +693,8 @@ namespace Exiv2 {
             subImage7Id,
             subImage8Id,
             subImage9Id,
-            panaRawIfdId,
+            subThumb1Id,
+            panaRawId,
             ifd2Id,
             ifd3Id
         };
@@ -765,7 +766,7 @@ namespace Exiv2 {
                 if (pos != ed.end() && sumToLong(*pos) > 32768) {
                     delTags = true;
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Exif tag " << pos->key() << " not encoded\n";
+                    EXV_WARNING << "Exif tag " << pos->key() << " not encoded\n";
 #endif
                     ed.erase(pos);
                 }
@@ -775,7 +776,7 @@ namespace Exiv2 {
                     pos = ed.findKey(ExifKey(filteredPvTags[i].key_));
                     if (pos != ed.end()) {
 #ifndef SUPPRESS_WARNINGS
-                        std::cerr << "Warning: Exif tag " << pos->key() << " not encoded\n";
+                        EXV_WARNING << "Exif tag " << pos->key() << " not encoded\n";
 #endif
                         ed.erase(pos);
                     }
@@ -784,9 +785,9 @@ namespace Exiv2 {
             case pttIfd:
                 if (delTags) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Exif IFD " << filteredPvTags[i].key_ << " not encoded\n";
+                    EXV_WARNING << "Exif IFD " << filteredPvTags[i].key_ << " not encoded\n";
 #endif
-                    eraseIfd(ed, ExifTags::ifdIdByIfdItem(filteredPvTags[i].key_));
+                    eraseIfd(ed, Internal::groupId(filteredPvTags[i].key_));
                 }
                 break;
             }
@@ -797,7 +798,7 @@ namespace Exiv2 {
             if (   pos->size() > 4096
                 && pos->tagName().substr(0, 2) == "0x") {
 #ifndef SUPPRESS_WARNINGS
-                std::cerr << "Warning: Exif tag " << pos->key() << " not encoded\n";
+                EXV_WARNING << "Exif tag " << pos->key() << " not encoded\n";
 #endif
                 pos = ed.erase(pos);
             }
@@ -935,7 +936,7 @@ namespace {
     {
         ed.erase(std::remove_if(ed.begin(),
                                 ed.end(),
-                                Exiv2::Internal::FindExifdatum(ifdId)),
+                                Exiv2::FindExifdatum(ifdId)),
                  ed.end());
     }
     //! @endcond
