@@ -21,7 +21,7 @@
 /*!
   @file    exif.hpp
   @brief   Encoding and decoding of Exif data
-  @version $Rev: 2045 $
+  @version $Rev: 2331 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created
@@ -161,12 +161,10 @@ namespace Exiv2 {
         std::string tagName() const;
         std::string tagLabel() const;
         uint16_t tag() const;
-        //! Return the IFD id
-        IfdId ifdId() const;
+        //! Return the IFD id as an integer. (Do not use, this is meant for library internal use.)
+        int ifdId() const;
         //! Return the name of the IFD
         const char* ifdName() const;
-        //! Return the related image item (deprecated)
-        std::string ifdItem() const;
         //! Return the index (unique id of this key within the original IFD)
         int idx() const;
         /*!
