@@ -22,13 +22,13 @@
   Abstract:  Command line program to display and manipulate image metadata.
 
   File:      exiv2.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2374 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   10-Dec-03, ahu: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: exiv2.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: exiv2.cpp 2374 2010-11-06 13:53:15Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -38,7 +38,7 @@ EXIV2_RCSID("@(#) $Id: exiv2.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
 # include "exv_conf.h"
 #endif
 
-#include "exiv2.hpp"
+#include "exiv2app.hpp"
 #include "actions.hpp"
 #include "utils.hpp"
 #include "convert.hpp"
@@ -256,6 +256,7 @@ void Params::help(std::ostream& os) const
        << _("   -h      Display this help and exit.\n")
        << _("   -V      Show the program version and exit.\n")
        << _("   -v      Be verbose during the program run.\n")
+       << _("   -q      Silence warnings and error messages during the program run (quiet).\n")
        << _("   -b      Show large binary values.\n")
        << _("   -u      Show unknown tags.\n")
        << _("   -g key  Only output info for this key (grep).\n")
@@ -336,6 +337,7 @@ int Params::option(int opt, const std::string& optarg, int optopt)
     case 'h': help_ = true; break;
     case 'V': version_ = true; break;
     case 'v': verbose_ = true; break;
+    case 'q': Exiv2::LogMsg::setLevel(Exiv2::LogMsg::mute); break;
     case 'k': preserve_ = true; break;
     case 'b': binary_ = false; break;
     case 'u': unknown_ = false; break;
@@ -807,6 +809,10 @@ int Params::getopt(int argc, char* const argv[])
             rc = 1;
         }
     }
+    if (rc == 0 && (!cmdFiles_.empty() || !cmdLines_.empty())) {
+        // We'll set them again, after reading the file
+        Exiv2::XmpProperties::unregisterNs();
+    }
     if (   !directory_.empty()
         && !(action_ == Action::insert || action_ == Action::extract)) {
         std::cerr << progname() << ": "
@@ -1046,8 +1052,7 @@ namespace {
                 try {
                     Exiv2::ExifKey exifKey(key);
                     metadataId = exif;
-                    defaultType = Exiv2::ExifTags::tagType(exifKey.tag(),
-                                                           exifKey.ifdId());
+                    defaultType = exifKey.defaultTypeId();
                 }
                 catch (const Exiv2::AnyError&) {}
             }
