@@ -20,7 +20,7 @@
  */
 /*
   File:      fujimn.cpp
-  Version:   $Rev: 2109 $
+  Version:   $Rev: 2346 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Gilles Caulier (gc) <caulier dot gilles at gmail dot com>
   History:   18-Feb-04, ahu: created
@@ -28,13 +28,14 @@
   Credits:   See header file.
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: fujimn.cpp 2109 2010-04-19 13:17:17Z cgilles $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: fujimn.cpp 2346 2010-09-10 16:36:33Z ahuggel $")
 
 // *****************************************************************************
 // included header files
 #include "types.hpp"
-#include "fujimn.hpp"
+#include "fujimn_int.hpp"
+#include "tags_int.hpp"
 #include "value.hpp"
 #include "i18n.h"                // NLS support.
 
@@ -48,6 +49,7 @@ EXIV2_RCSID("@(#) $Id: fujimn.cpp 2109 2010-04-19 13:17:17Z cgilles $")
 // *****************************************************************************
 // class member definitions
 namespace Exiv2 {
+    namespace Internal {
 
     //! OffOn, multiple tags
     extern const TagDetails fujiOffOn[] = {
@@ -73,7 +75,8 @@ namespace Exiv2 {
         {  769, N_("Fluorescent (warm white)") },
         {  770, N_("Fluorescent (cool white)") },
         { 1024, N_("Incandescent")             },
-        { 3480, N_("Custom")                   }
+        { 3480, N_("Custom")                   },
+        { 3480, N_("Custom")                   } // To silence compiler warning
     };
 
     //! Color, tag 0x1003
@@ -81,7 +84,8 @@ namespace Exiv2 {
         {   0, N_("Normal")               },
         { 256, N_("High")                 },
         { 512, N_("Low")                  },
-        { 768, N_("None (black & white)") }
+        { 768, N_("None (black & white)") },
+        { 768, N_("None (black & white)") }     // To silence compiler warning
     };
 
     //! Tone, tag 0x1004
@@ -96,7 +100,8 @@ namespace Exiv2 {
         { 0, N_("Auto")              },
         { 1, N_("On")                },
         { 2, N_("Off")               },
-        { 3, N_("Red-eye reduction") }
+        { 3, N_("Red-eye reduction") },
+        { 3, N_("Red-eye reduction") }          // To silence compiler warning
     };
 
     //! FocusMode, tag 0x1021
@@ -173,109 +178,108 @@ namespace Exiv2 {
     const TagInfo FujiMakerNote::tagInfo_[] = {
         TagInfo(0x0000, "Version", N_("Version"),
                 N_("Fujifilm Makernote version"),
-                fujiIfdId, makerTags, undefined, printValue),
+                fujiId, makerTags, undefined, -1, printValue),
         TagInfo(0x0010, "SerialNumber", N_("Serial Number"),
                 N_("This number is unique, and contains the date of manufacture, "
                    "but is not the same as the number printed on the camera body."),
-                fujiIfdId, makerTags, asciiString, printValue),
+                fujiId, makerTags, asciiString, -1, printValue),
         TagInfo(0x1000, "Quality", N_("Quality"),
                 N_("Image quality setting"),
-                fujiIfdId, makerTags, asciiString, printValue),
+                fujiId, makerTags, asciiString, -1, printValue),
         TagInfo(0x1001, N_("Sharpness"), N_("Sharpness"),
                 N_("Sharpness setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiSharpness)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiSharpness)),
         TagInfo(0x1002, "WhiteBalance", N_("White Balance"),
                 N_("White balance setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiWhiteBalance)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiWhiteBalance)),
         TagInfo(0x1003, "Color", N_("Color"),
                 N_("Chroma saturation setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiColor)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiColor)),
         TagInfo(0x1004, "Tone", N_("Tone"),
                 N_("Contrast setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiTone)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiTone)),
         TagInfo(0x1010, "FlashMode", N_("Flash Mode"),
                 N_("Flash firing mode setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiFlashMode)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiFlashMode)),
         TagInfo(0x1011, "FlashStrength", N_("Flash Strength"),
                 N_("Flash firing strength compensation setting"),
-                fujiIfdId, makerTags, signedRational, printValue),
+                fujiId, makerTags, signedRational, -1, printValue),
         TagInfo(0x1020, "Macro", N_("Macro"),
                 N_("Macro mode setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiOffOn)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiOffOn)),
         TagInfo(0x1021, "FocusMode", N_("Focus Mode"),
                 N_("Focusing mode setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiFocusMode)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiFocusMode)),
         TagInfo(0x1022, "0x1022", "0x1022",
                 N_("Unknown"),
-                fujiIfdId, makerTags, unsignedShort, printValue),
+                fujiId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x1030, "SlowSync", N_("Slow Sync"),
                 N_("Slow synchro mode setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiOffOn)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiOffOn)),
         TagInfo(0x1031, "PictureMode", N_("Picture Mode"),
                 N_("Picture mode setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiPictureMode)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiPictureMode)),
         TagInfo(0x1032, "0x1032", "0x1032",
                 N_("Unknown"),
-                fujiIfdId, makerTags, unsignedShort, printValue),
+                fujiId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x1100, "Continuous", N_("Continuous"),
                 N_("Continuous shooting or auto bracketing setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiContinuous)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiContinuous)),
         TagInfo(0x1101, "SequenceNumber", N_("Sequence Number"),
                 N_("Sequence number"),
-                fujiIfdId, makerTags, unsignedShort, printValue),
+                fujiId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x1200, "0x1200", "0x1200",
                 N_("Unknown"),
-                fujiIfdId, makerTags, unsignedShort, printValue),
+                fujiId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x1210, "FinePixColor", N_("FinePix Color"),
                 N_("Fuji FinePix color setting"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiFinePixColor)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiFinePixColor)),
         TagInfo(0x1300, "BlurWarning", N_("Blur Warning"),
                 N_("Blur warning status"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiOffOn)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiOffOn)),
         TagInfo(0x1301, "FocusWarning", N_("Focus Warning"),
                 N_("Auto Focus warning status"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiOffOn)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiOffOn)),
         TagInfo(0x1302, "ExposureWarning", N_("Exposure Warning"),
                 N_("Auto exposure warning status"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiOffOn)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiOffOn)),
         TagInfo(0x1400, "DynamicRange", N_("Dynamic Range"),
                 N_("Dynamic range"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiDynamicRange)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiDynamicRange)),
         TagInfo(0x1401, "FilmMode", N_("Film Mode"),
                 N_("Film mode"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiFilmMode)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiFilmMode)),
         TagInfo(0x1402, "DynamicRangeSetting", N_("Dynamic Range Setting"),
                 N_("Dynamic range settings"),
-                fujiIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(fujiDynamicRangeSetting)),
+                fujiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(fujiDynamicRangeSetting)),
         TagInfo(0x1403, "DevelopmentDynamicRange", N_("Development Dynamic Range"),
                 N_("Development dynamic range"),
-                fujiIfdId, makerTags, unsignedShort, printValue),
+                fujiId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x1404, "MinFocalLength", N_("Minimum Focal Length"),
                 N_("Minimum focal length"),
-                fujiIfdId, makerTags, unsignedRational, printValue),
+                fujiId, makerTags, unsignedRational, -1, printValue),
         TagInfo(0x1405, "MaxFocalLength", N_("Maximum Focal Length"),
                 N_("Maximum focal length"),
-                fujiIfdId, makerTags, unsignedRational, printValue),
+                fujiId, makerTags, unsignedRational, -1, printValue),
         TagInfo(0x1406, "MaxApertureAtMinFocal", N_("Maximum Aperture at Mininimum Focal"),
                 N_("Maximum aperture at mininimum focal"),
-                fujiIfdId, makerTags, unsignedRational, printValue),
+                fujiId, makerTags, unsignedRational, -1, printValue),
         TagInfo(0x1407, "MaxApertureAtMaxFocal", N_("Maximum Aperture at Maxinimum Focal"),
                 N_("Maximum aperture at maxinimum focal"),
-                fujiIfdId, makerTags, unsignedRational, printValue),
+                fujiId, makerTags, unsignedRational, -1, printValue),
         TagInfo(0x8000, "FileSource", N_("File Source"),
                 N_("File source"),
-                fujiIfdId, makerTags, asciiString, printValue),
+                fujiId, makerTags, asciiString, -1, printValue),
         TagInfo(0x8002, "OrderNumber", N_("Order Number"),
                 N_("Order number"),
-                fujiIfdId, makerTags, unsignedLong, printValue),
+                fujiId, makerTags, unsignedLong, -1, printValue),
         TagInfo(0x8003, "FrameNumber", N_("Frame Number"),
                 N_("Frame number"),
-                fujiIfdId, makerTags, unsignedShort, printValue),
-
+                fujiId, makerTags, unsignedShort, -1, printValue),
         // End of list marker
         TagInfo(0xffff, "(UnknownFujiMakerNoteTag)", "(UnknownFujiMakerNoteTag)",
                 N_("Unknown FujiMakerNote tag"),
-                fujiIfdId, makerTags, invalidTypeId, printValue)
+                fujiId, makerTags, asciiString, -1, printValue)
     };
 
     const TagInfo* FujiMakerNote::tagList()
@@ -283,4 +287,4 @@ namespace Exiv2 {
         return tagInfo_;
     }
 
-}                                       // namespace Exiv2
+}}                                      // namespace Internal, Exiv2
