@@ -20,14 +20,14 @@
  */
 /*
   File:      futils.cpp
-  Version:   $Rev: 2076 $
+  Version:   $Rev: 2286 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
              02-Apr-05, ahu: moved to Exiv2 namespace
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: futils.cpp 2076 2010-04-14 08:09:11Z cgilles $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: futils.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
 
 // *****************************************************************************
 // included header files
