@@ -20,13 +20,13 @@
  */
 /*
   File:      gifimage.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2286 $
   Author(s): Marco Piovanelli, Ovolab (marco)
   History:   26-Feb-2007, marco: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: gifimage.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: gifimage.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
 
 //#define DEBUG 1
 
