@@ -20,13 +20,13 @@
  */
 /*
   File:      iptc.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2344 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
   History:   31-July-04, brad: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: iptc.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: iptc.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -451,18 +451,16 @@ namespace Exiv2 {
                 int rc = 0;
                 if ((rc = readData(iptcData, dataSet, record, pRead, sizeData)) != 0) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: "
-                              << "Failed to read IPTC dataset "
-                              << IptcKey(dataSet, record)
-                              << " (rc = " << rc << "); skipped.\n";
+                    EXV_WARNING << "Failed to read IPTC dataset "
+                                << IptcKey(dataSet, record)
+                                << " (rc = " << rc << "); skipped.\n";
 #endif
                 }
             }
 #ifndef SUPPRESS_WARNINGS
             else {
-                std::cerr << "Warning: "
-                          << "IPTC dataset " << IptcKey(dataSet, record)
-                          << " has invalid size " << sizeData << "; skipped.\n";
+                EXV_WARNING << "IPTC dataset " << IptcKey(dataSet, record)
+                            << " has invalid size " << sizeData << "; skipped.\n";
             }
 #endif
             pRead += sizeData;
