@@ -20,14 +20,14 @@
  */
 /*
   File:      jp2image.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2344 $
   Author(s): Marco Piovanelli, Ovolab (marco)
   Author(s): Gilles Caulier (cgilles) <caulier dot gilles at gmail dot com>
   History:   12-Mar-2007, marco: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: jp2image.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: jp2image.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
 
 // *****************************************************************************
 
@@ -286,7 +286,7 @@ namespace Exiv2
                             else
                             {
 #ifndef SUPPRESS_WARNINGS
-                                std::cerr << "Exiv2::Jp2Image::readMetadata: Failed to decode Exif metadata.\n";
+                                EXV_WARNING << "Failed to decode Exif metadata.\n";
 #endif
                                 exifData_.clear();
                             }
@@ -305,7 +305,7 @@ namespace Exiv2
                             if (IptcParser::decode(iptcData_, rawData.pData_, rawData.size_))
                             {
 #ifndef SUPPRESS_WARNINGS
-                                std::cerr << "Warning: Failed to decode IPTC metadata.\n";
+                                EXV_WARNING << "Failed to decode IPTC metadata.\n";
 #endif
                                 iptcData_.clear();
                             }
@@ -327,9 +327,8 @@ namespace Exiv2
                             if (idx != std::string::npos && idx > 0)
                             {
 #ifndef SUPPRESS_WARNINGS
-                                std::cerr << "Exiv2::Jp2Image::readMetadata: Removing "
-                                          << static_cast<uint32_t>(idx)
-                                          << " characters from the beginning of the XMP packet\n";
+                                EXV_WARNING << "Removing " << static_cast<uint32_t>(idx)
+                                            << " characters from the beginning of the XMP packet\n";
 #endif
                                 xmpPacket_ = xmpPacket_.substr(idx);
                             }
@@ -337,7 +336,7 @@ namespace Exiv2
                             if (xmpPacket_.size() > 0 && XmpParser::decode(xmpData_, xmpPacket_))
                             {
 #ifndef SUPPRESS_WARNINGS
-                                std::cerr << "Exiv2::Jp2Image::readMetadata: Failed to decode XMP metadata.\n";
+                                EXV_WARNING << "Failed to decode XMP metadata.\n";
 #endif
                             }
                         }
@@ -532,7 +531,7 @@ namespace Exiv2
                         if (XmpParser::encode(xmpPacket_, xmpData_) > 1)
                         {
 #ifndef SUPPRESS_WARNINGS
-                            std::cerr << "Error: Failed to encode XMP metadata.\n";
+                            EXV_ERROR << "Failed to encode XMP metadata.\n";
 #endif
                         }
                     }
