@@ -20,7 +20,7 @@
  */
 /*
   File:      jpgimage.cpp
-  Version:   $Rev: 2206 $
+  Version:   $Rev: 2344 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
              Volker Grabsch (vog) <vog@notjusthosting.com>
@@ -28,8 +28,8 @@
   History:   15-Jan-05, brad: split out from image.cpp
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: jpgimage.cpp 2206 2010-04-28 15:20:01Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: jpgimage.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -347,7 +347,7 @@ namespace Exiv2 {
                 setByteOrder(bo);
                 if (rawExif.size_ > 0 && byteOrder() == invalidByteOrder) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode Exif metadata.\n";
+                    EXV_WARNING << "Failed to decode Exif metadata.\n";
 #endif
                     exifData_.clear();
                 }
@@ -368,7 +368,7 @@ namespace Exiv2 {
                 xmpPacket_.assign(reinterpret_cast<char*>(xmpPacket.pData_), xmpPacket.size_);
                 if (xmpPacket_.size() > 0 && XmpParser::decode(xmpData_, xmpPacket_)) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode XMP metadata.\n";
+                    EXV_WARNING << "Failed to decode XMP metadata.\n";
 #endif
                 }
                 --search;
@@ -474,7 +474,7 @@ namespace Exiv2 {
                                       &iptcBlob[0],
                                       static_cast<uint32_t>(iptcBlob.size()))) {
 #ifndef SUPPRESS_WARNINGS
-                std::cerr << "Warning: Failed to decode IPTC metadata.\n";
+                EXV_WARNING << "Failed to decode IPTC metadata.\n";
 #endif
                 iptcData_.clear();
             }
@@ -482,7 +482,7 @@ namespace Exiv2 {
 
         if (rc != 0) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: JPEG format error, rc = " << rc << "\n";
+            EXV_WARNING << "JPEG format error, rc = " << rc << "\n";
 #endif
         }
     } // JpegBase::readMetadata
@@ -698,7 +698,7 @@ namespace Exiv2 {
                 if (writeXmpFromPacket() == false) {
                     if (XmpParser::encode(xmpPacket_, xmpData_, XmpParser::useCompactFormat | XmpParser::omitAllFormatting) > 1) {
 #ifndef SUPPRESS_WARNINGS
-                        std::cerr << "Error: Failed to encode XMP metadata.\n";
+                        EXV_ERROR << "Failed to encode XMP metadata.\n";
 #endif
                     }
                 }
