@@ -24,7 +24,7 @@
            vendor specific makernote implementations.<BR>References:<BR>
   [1] <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/">ExifTool</a> by Phil Harvey<BR>
   [2] <a href="http://www.cybercom.net/~dcoffin/dcraw/">Decoding raw digital photos in Linux</a> by Dave Coffin
-  @version $Rev: 2239 $
+  @version $Rev: 2357 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    11-Apr-06, ahu: created
@@ -35,6 +35,7 @@
 // *****************************************************************************
 // included header files
 #include "tifffwd_int.hpp"
+#include "tags_int.hpp"
 #include "types.hpp"
 
 // + standard includes
@@ -45,102 +46,21 @@
 namespace Exiv2 {
     namespace Internal {
 
-    namespace Group {
-        const uint16_t olympmn   = 257; //!< any Olympus makernote
-        const uint16_t fujimn    = 258; //!< Fujifilm makernote
-        const uint16_t canonmn   = 259; //!< Canon makernote
-        const uint16_t canoncs   = 260; //!< Canon camera settings
-        const uint16_t canonsi   = 261; //!< Canon shot info
-        const uint16_t canoncf   = 262; //!< Canon custom functions
-        const uint16_t nikonmn   = 263; //!< Any Nikon makernote (pseudo group)
-        const uint16_t nikon1mn  = 264; //!< Nikon1 makernote
-        const uint16_t nikon2mn  = 265; //!< Nikon2 makernote
-        const uint16_t nikon3mn  = 266; //!< Nikon3 makernote
-        const uint16_t panamn    = 267; //!< Panasonic makernote
-        const uint16_t sigmamn   = 268; //!< Sigma makernote
-        const uint16_t sonymn    = 269; //!< Any Sony makernote (pseudo group)
-        const uint16_t sony1mn   = 270; //!< Sony1 makernote
-        const uint16_t sony2mn   = 271; //!< Sony2 makernote
-        const uint16_t minoltamn = 272; //!< Minolta makernote
-        const uint16_t minocso   = 273; //!< Minolta camera settings (old)
-        const uint16_t minocsn   = 274; //!< Minolta camera settings (new)
-        const uint16_t minocs5   = 275; //!< Minolta camera settings (D5)
-        const uint16_t minocs7   = 276; //!< Minolta camera settings (D7)
-        const uint16_t canonpi   = 277; //!< Canon picture info
-        const uint16_t canonpa   = 278; //!< Canon panorama
-        const uint16_t pentaxmn  = 279; //!< Pentax makernote
-        const uint16_t nikonpv   = 280; //!< Nikon preview sub-IFD
-        const uint16_t olymp1mn  = 281; //!< Olympus makernote
-        const uint16_t olymp2mn  = 282; //!< Olympus II makernote
-        const uint16_t olympcs   = 283; //!< Olympus camera settings
-        const uint16_t olympeq   = 284; //!< Olympus equipment tags
-        const uint16_t olymprd   = 285; //!< Olympus raw development tags
-        const uint16_t olymprd2  = 286; //!< Olympus raw development 2 tags
-        const uint16_t olympip   = 287; //!< Olympus image processing tags
-        const uint16_t olympfi   = 288; //!< Olympus focus info tags
-        const uint16_t olympfe1  = 289; //!< Olympus FE 1 tags
-        const uint16_t olympfe2  = 290; //!< Olympus FE 2 tags
-        const uint16_t olympfe3  = 291; //!< Olympus FE 3 tags
-        const uint16_t olympfe4  = 292; //!< Olympus FE 4 tags
-        const uint16_t olympfe5  = 293; //!< Olympus FE 5 tags
-        const uint16_t olympfe6  = 294; //!< Olympus FE 6 tags
-        const uint16_t olympfe7  = 295; //!< Olympus FE 7 tags
-        const uint16_t olympfe8  = 296; //!< Olympus FE 8 tags
-        const uint16_t olympfe9  = 297; //!< Olympus FE 9 tags
-        const uint16_t olympri   = 298; //!< Olympus raw info tags
-        const uint16_t nikonwt   = 299; //!< Nikon World Time tags
-        const uint16_t nikonii   = 300; //!< Nikon ISO Info tags
-        const uint16_t nikonld1  = 301; //!< Nikon Lens Data 1 tags
-        const uint16_t nikonld2  = 302; //!< Nikon Lens Data 2 tags
-        const uint16_t nikonld3  = 303; //!< Nikon Lens Data 3 tags
-        const uint16_t nikoncb1  = 304; //!< Nikon Color Balance 1 Tags
-        const uint16_t nikoncb2  = 305; //!< Nikon Color Balance 2 Tags
-        const uint16_t nikoncb2a = 306; //!< Nikon Color Balance 2 Tags
-        const uint16_t nikoncb2b = 307; //!< Nikon Color Balance 2 Tags
-        const uint16_t nikoncb3  = 308; //!< Nikon Color Balance 3 Tags
-        const uint16_t nikoncb4  = 309; //!< Nikon Color Balance 4 Tags
-        const uint16_t nikonvr   = 310; //!< Nikon Vibration Reduction Tags
-        const uint16_t nikonpc   = 311; //!< Nikon Picture Control Tags
-        const uint16_t nikonaf   = 312; //!< Nikon Auto Focus Tags
-        const uint16_t nikonsi1  = 313; //!< Nikon Shot Info D80 Tags
-        const uint16_t nikonsi2  = 314; //!< Nikon Shot Info D40 Tags
-        const uint16_t nikonsi3  = 315; //!< Nikon Shot Info D300 Tags (a)
-        const uint16_t nikonsi4  = 316; //!< Nikon Shot Info D300 Tags (b)
-        const uint16_t nikonsi5  = 317; //!< Nikon Shot Info v2.* Tags
-        const uint16_t nikonsi6  = 318; //!< Nikon Shot Info v1.* Tags
-        const uint16_t canonfi   = 320; //!< Canon File Info
-        const uint16_t sonymltmn = 330; //!< Sony Minolta Makernotes
-        const uint16_t sony1cs   = 331; //!< Sony Camera Settings (in Sony1 makernote)
-        const uint16_t sony1cs2  = 332; //!< Sony Camera Settings 2 (in Sony1 makernote)
-        const uint16_t sony1mcso = 333; //!< Minolta (old) Camera Settings (in Sony1 makernote)
-        const uint16_t sony1mcsn = 334; //!< Minolta (new) Camera Settings (in Sony1 makernote)
-        const uint16_t sony1mcsa100=335;//!< Sony A100 Camera Settings (in Sony1 makernote)
-        const uint16_t sony1mcs7 = 336; //!< Minolta D7 Camera Settings (in Sony1 makernote)
-        const uint16_t sony2cs   = 337; //!< Sony Camera Settings (in Sony2 makernote)
-        const uint16_t sony2cs2  = 338; //!< Sony Camera Settings 2 (in Sony2 makernote)
-        const uint16_t nikonfi   = 362; //!< Nikon File Info Tags
-        const uint16_t nikonaf2  = 363; //!< Nikon Auto Focus 2 Tags
-        const uint16_t nikonme   = 364; //!< Nikon Multi Exposure Tags
-        const uint16_t nikonfl1  = 365; //!< Nikon Flash Info 1 Tags
-        const uint16_t nikonfl2  = 366; //!< Nikon Flash Info 2 Tags
-        const uint16_t nikonfl3  = 367; //!< Nikon Flash Info 3 Tags
-    }
-
 // *****************************************************************************
 // class definitions
 
     //! Type for a pointer to a function creating a makernote (image)
     typedef TiffComponent* (*NewMnFct)(uint16_t    tag,
-                                       uint16_t    group,
-                                       uint16_t    mnGroup,
+                                       IfdId       group,
+                                       IfdId       mnGroup,
                                        const byte* pData,
                                        uint32_t    size,
                                        ByteOrder   byteOrder);
 
     //! Type for a pointer to a function creating a makernote (group)
     typedef TiffComponent* (*NewMnFct2)(uint16_t   tag,
-                                        uint16_t   group,
-                                        uint16_t   mnGroup);
+                                        IfdId      group,
+                                        IfdId      mnGroup);
 
     //! Makernote registry structure
     struct TiffMnRegistry {
@@ -155,11 +75,11 @@ namespace Exiv2 {
         bool operator==(const std::string& key) const;
 
         //! Compare a TiffMnRegistry structure with a makernote group
-        bool operator==(const uint16_t& key) const;
+        bool operator==(IfdId key) const;
 
         // DATA
         const char* make_;                      //!< Camera make
-        uint16_t    mnGroup_;                   //!< Group identifier
+        IfdId       mnGroup_;                   //!< Group identifier
         NewMnFct    newMnFct_;                  //!< Makernote create function (image)
         NewMnFct2   newMnFct2_;                 //!< Makernote create function (group)
     };
@@ -181,7 +101,7 @@ namespace Exiv2 {
                  file dependencies.
         */
         static TiffComponent* create(uint16_t           tag,
-                                     uint16_t           group,
+                                     IfdId              group,
                                      const std::string& make,
                                      const byte*        pData,
                                      uint32_t           size,
@@ -191,8 +111,8 @@ namespace Exiv2 {
                  when a makernote is written back from Exif tags.
          */
         static TiffComponent* create(uint16_t           tag,
-                                     uint16_t           group,
-                                     uint16_t           mnGroup);
+                                     IfdId              group,
+                                     IfdId              mnGroup);
 
     protected:
         //! Prevent destruction (needed if used as a policy class)
@@ -243,7 +163,7 @@ namespace Exiv2 {
                  to the start of the TIFF header. \em mnOffset is the offset
                  to the makernote from the start of the TIFF header.
          */
-        virtual uint32_t baseOffset(uint32_t /*mnOffset*/) const;
+        virtual uint32_t baseOffset(uint32_t mnOffset) const;
         //@}
 
     }; // class MnHeader
@@ -471,6 +391,29 @@ namespace Exiv2 {
 
     }; // class PentaxMnHeader
 
+    //! Header of a Samsung Makernote, only used for the relative offset
+    class SamsungMnHeader : public MnHeader {
+    public:
+        //! @name Creators
+        //@{
+        //! Default constructor
+        SamsungMnHeader();
+        //@}
+        //! @name Manipulators
+        //@{
+        virtual bool read(const byte* pData,
+                          uint32_t    size,
+                          ByteOrder   byteOrder);
+        //@}
+        //! @name Accessors
+        //@{
+        virtual uint32_t size() const;
+        virtual uint32_t write(IoWrapper& ioWrapper, ByteOrder byteOrder) const;
+        virtual uint32_t baseOffset(uint32_t mnOffset) const;
+        //@}
+
+    }; // class SamsungMnHeader
+
     //! Header of a Sigma Makernote
     class SigmaMnHeader : public MnHeader {
     public:
@@ -539,125 +482,138 @@ namespace Exiv2 {
 
     //! Function to create a simple IFD makernote (Canon, Minolta, Nikon1)
     TiffComponent* newIfdMn(uint16_t    tag,
-                            uint16_t    group,
-                            uint16_t    mnGroup,
+                            IfdId       group,
+                            IfdId       mnGroup,
                             const byte* pData,
                             uint32_t    size,
                             ByteOrder   byteOrder);
 
     //! Function to create a simple IFD makernote (Canon, Minolta, Nikon1)
     TiffComponent* newIfdMn2(uint16_t tag,
-                             uint16_t group,
-                             uint16_t mnGroup);
+                             IfdId    group,
+                             IfdId    mnGroup);
 
     //! Function to create an Olympus makernote
     TiffComponent* newOlympusMn(uint16_t    tag,
-                                uint16_t    group,
-                                uint16_t    mnGroup,
+                                IfdId       group,
+                                IfdId       mnGroup,
                                 const byte* pData,
                                 uint32_t    size,
                                 ByteOrder   byteOrder);
 
     //! Function to create an Olympus makernote
     TiffComponent* newOlympusMn2(uint16_t tag,
-                                 uint16_t group,
-                                 uint16_t mnGroup);
+                                 IfdId    group,
+                                 IfdId    mnGroup);
 
     //! Function to create an Olympus II makernote
     TiffComponent* newOlympus2Mn2(uint16_t tag,
-                                 uint16_t group,
-                                 uint16_t mnGroup);
+                                 IfdId     group,
+                                 IfdId     mnGroup);
 
     //! Function to create a Fujifilm makernote
     TiffComponent* newFujiMn(uint16_t    tag,
-                             uint16_t    group,
-                             uint16_t    mnGroup,
+                             IfdId       group,
+                             IfdId       mnGroup,
                              const byte* pData,
                              uint32_t    size,
                              ByteOrder   byteOrder);
 
     //! Function to create a Fujifilm makernote
     TiffComponent* newFujiMn2(uint16_t tag,
-                              uint16_t group,
-                              uint16_t mnGroup);
+                              IfdId    group,
+                              IfdId    mnGroup);
 
     /*!
       @brief Function to create a Nikon makernote. This will create the
              appropriate Nikon 1, 2 or 3 makernote, based on the arguments.
      */
     TiffComponent* newNikonMn(uint16_t    tag,
-                              uint16_t    group,
-                              uint16_t    mnGroup,
+                              IfdId       group,
+                              IfdId       mnGroup,
                               const byte* pData,
                               uint32_t    size,
                               ByteOrder   byteOrder);
 
     //! Function to create a Nikon2 makernote
     TiffComponent* newNikon2Mn2(uint16_t tag,
-                                uint16_t group,
-                                uint16_t mnGroup);
+                                IfdId    group,
+                                IfdId    mnGroup);
 
     //! Function to create a Nikon3 makernote
     TiffComponent* newNikon3Mn2(uint16_t tag,
-                                uint16_t group,
-                                uint16_t mnGroup);
+                                IfdId    group,
+                                IfdId    mnGroup);
 
     //! Function to create a Panasonic makernote
     TiffComponent* newPanasonicMn(uint16_t    tag,
-                                  uint16_t    group,
-                                  uint16_t    mnGroup,
+                                  IfdId       group,
+                                  IfdId       mnGroup,
                                   const byte* pData,
                                   uint32_t    size,
                                   ByteOrder   byteOrder);
 
     //! Function to create a Panasonic makernote
     TiffComponent* newPanasonicMn2(uint16_t tag,
-                                   uint16_t group,
-                                   uint16_t mnGroup);
+                                   IfdId    group,
+                                   IfdId    mnGroup);
 
     //! Function to create an Pentax makernote
     TiffComponent* newPentaxMn(uint16_t    tag,
-                               uint16_t    group,
-                               uint16_t    mnGroup,
+                               IfdId       group,
+                               IfdId       mnGroup,
                                const byte* pData,
                                uint32_t    size,
                                ByteOrder   byteOrder);
 
     //! Function to create an Pentax makernote
     TiffComponent* newPentaxMn2(uint16_t tag,
-                                uint16_t group,
-                                uint16_t mnGroup);
+                                IfdId    group,
+                                IfdId    mnGroup);
+
+    //! Function to create a Samsung makernote
+    TiffComponent* newSamsungMn(uint16_t    tag,
+                                IfdId       group,
+                                IfdId       mnGroup,
+                                const byte* pData,
+                                uint32_t    size,
+                                ByteOrder   byteOrder);
+
+    //! Function to create a Samsung makernote
+    TiffComponent* newSamsungMn2(uint16_t tag,
+                                 IfdId    group,
+                                 IfdId    mnGroup);
 
     //! Function to create a Sigma makernote
     TiffComponent* newSigmaMn(uint16_t    tag,
-                              uint16_t    group,
-                              uint16_t    mnGroup,
+                              IfdId       group,
+                              IfdId       mnGroup,
                               const byte* pData,
                               uint32_t    size,
                               ByteOrder   byteOrder);
 
     //! Function to create a Sigma makernote
     TiffComponent* newSigmaMn2(uint16_t tag,
-                               uint16_t group,
-                               uint16_t mnGroup);
+                               IfdId    group,
+                               IfdId    mnGroup);
 
     //! Function to create a Sony makernote
     TiffComponent* newSonyMn(uint16_t    tag,
-                             uint16_t    group,
-                             uint16_t    mnGroup,
+                             IfdId       group,
+                             IfdId       mnGroup,
                              const byte* pData,
                              uint32_t    size,
                              ByteOrder   byteOrder);
 
     //! Function to create a Sony1 makernote
     TiffComponent* newSony1Mn2(uint16_t tag,
-                               uint16_t group,
-                               uint16_t mnGroup);
+                               IfdId    group,
+                               IfdId    mnGroup);
 
     //! Function to create a Sony2 makernote
     TiffComponent* newSony2Mn2(uint16_t tag,
-                               uint16_t group,
-                               uint16_t mnGroup);
+                               IfdId    group,
+                               IfdId    mnGroup);
 
     /*!
       @brief Function to select cfg + def of the Sony Camera Settings complex binary array.
