@@ -20,15 +20,15 @@
  */
 /*
   File:      metadatum.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2286 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
   History:   26-Jan-04, ahu: created
              31-Jul-04, brad: isolated as a component
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: metadatum.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: metadatum.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
 
 // *****************************************************************************
 // included header files
