@@ -20,14 +20,14 @@
  */
 /*
   File:      orfimage.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2336 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   13-May-06, ahu: created
   Credits:   See header file
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: orfimage.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: orfimage.cpp 2336 2010-08-30 19:33:07Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -176,7 +176,7 @@ namespace Exiv2 {
 
         // Delete IFDs which do not occur in TIFF images
         static const IfdId filteredIfds[] = {
-            panaRawIfdId
+            panaRawId
         };
         for (unsigned int i = 0; i < EXV_COUNTOF(filteredIfds); ++i) {
 #ifdef DEBUG
