@@ -20,7 +20,7 @@
  */
 /*
   File:      pentaxmn.cpp
-  Version:   $Rev: 2227 $
+  Version:   $Rev: 2346 $
   Author(s): Michal Cihar <michal@cihar.com>
   Based on fujimn.cpp by:
              Andreas Huggel (ahu) <ahuggel@gmx.net>
@@ -29,13 +29,13 @@
   Credits:   See header file.
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: pentaxmn.cpp 2227 2010-05-24 04:56:56Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: pentaxmn.cpp 2346 2010-09-10 16:36:33Z ahuggel $")
 
 // *****************************************************************************
 // included header files
 #include "types.hpp"
-#include "pentaxmn.hpp"
+#include "pentaxmn_int.hpp"
 #include "value.hpp"
 #include "i18n.h"                // NLS support.
 
@@ -49,6 +49,7 @@ EXIV2_RCSID("@(#) $Id: pentaxmn.cpp 2227 2010-05-24 04:56:56Z ahuggel $")
 // *****************************************************************************
 // class member definitions
 namespace Exiv2 {
+    namespace Internal {
 
     //! ShootingMode, tag 0x0001
     extern const TagDetails pentaxShootingMode[] = {
@@ -338,14 +339,15 @@ namespace Exiv2 {
 
     //! Saturation, tag 0x001f
     extern const TagDetails pentaxSaturation[] = {
-        {    0, N_("Low") },
-        {    1, N_("Normal") },
-        {    2, N_("High") },
-        {    3, N_("Med Low") },
-        {    4, N_("Med High") },
-        {    5, N_("Very Low") },
-        {    6, N_("Very High") },
-        {    65535, N_("None") },
+        {     0, N_("Low")       },
+        {     1, N_("Normal")    },
+        {     2, N_("High")      },
+        {     3, N_("Med Low")   },
+        {     4, N_("Med High")  },
+        {     5, N_("Very Low")  },
+        {     6, N_("Very High") },
+        { 65535, N_("None")      },
+        { 65535, N_("None")      }              // To silence compiler warning
     };
 
     //! Contrast, tag 0x0020
@@ -862,266 +864,266 @@ namespace Exiv2 {
     const TagInfo PentaxMakerNote::tagInfo_[] = {
         TagInfo(0x0000, "Version", N_("Version"),
                 N_("Pentax Makernote version"),
-                pentaxIfdId, makerTags, undefined, printPentaxVersion),
+                pentaxId, makerTags, undefined, -1, printPentaxVersion),
         TagInfo(0x0001, "Mode", N_("Shooting mode"),
                 N_("Camera shooting mode"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxShootingMode)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxShootingMode)),
         TagInfo(0x0002, "PreviewResolution", N_("Resolution of a preview image"),
                 N_("Resolution of a preview image"),
-                pentaxIfdId, makerTags, undefined, printPentaxResolution),
+                pentaxId, makerTags, undefined, -1, printPentaxResolution),
         TagInfo(0x0003, "PreviewLength", N_("Length of a preview image"),
                 N_("Size of an IFD containing a preview image"),
-                pentaxIfdId, makerTags, undefined, printValue),
+                pentaxId, makerTags, undefined, -1, printValue),
         TagInfo(0x0004, "PreviewOffset", N_("Pointer to a preview image"),
                 N_("Offset to an IFD containing a preview image"),
-                pentaxIfdId, makerTags, undefined, printValue),
+                pentaxId, makerTags, undefined, -1, printValue),
         TagInfo(0x0005, "ModelID", N_("Model identification"),
                 N_("Pentax model idenfication"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxModel)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxModel)),
         TagInfo(0x0006, "Date", N_("Date"),
                 N_("Date"),
-                pentaxIfdId, makerTags, undefined, printPentaxDate),
+                pentaxId, makerTags, undefined, -1, printPentaxDate),
         TagInfo(0x0007, "Time", N_("Time"),
                 N_("Time"),
-                pentaxIfdId, makerTags, undefined, printPentaxTime),
+                pentaxId, makerTags, undefined, -1, printPentaxTime),
         TagInfo(0x0008, "Quality", N_("Image quality"),
                 N_("Image quality settings"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxQuality)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxQuality)),
         TagInfo(0x0009, "Size", N_("Image size"),
                 N_("Image size settings"),
-                pentaxIfdId, makerTags, unsignedLong, EXV_PRINT_TAG(pentaxSize)),
+                pentaxId, makerTags, unsignedLong, -1, EXV_PRINT_TAG(pentaxSize)),
         /* Some missing ! */
         TagInfo(0x000c, "Flash", N_("Flash mode"),
                 N_("Flash mode settings"),
-                pentaxIfdId, makerTags, unsignedLong, EXV_PRINT_TAG(pentaxFlash)),
+                pentaxId, makerTags, unsignedLong, -1, EXV_PRINT_TAG(pentaxFlash)),
         TagInfo(0x000d, "Focus", N_("Focus mode"),
                 N_("Focus mode settings"),
-                pentaxIfdId, makerTags, unsignedLong, EXV_PRINT_TAG(pentaxFocus)),
+                pentaxId, makerTags, unsignedLong, -1, EXV_PRINT_TAG(pentaxFocus)),
         TagInfo(0x000e, "AFPoint", N_("AF point"),
                 N_("Selected AF point"),
-                pentaxIfdId, makerTags, unsignedLong, EXV_PRINT_TAG(pentaxAFPoint)),
+                pentaxId, makerTags, unsignedLong, -1, EXV_PRINT_TAG(pentaxAFPoint)),
         TagInfo(0x000F, "AFPointInFocus", N_("AF point in focus"),
                 N_("AF point in focus"),
-                pentaxIfdId, makerTags, unsignedLong, EXV_PRINT_TAG(pentaxAFPointFocus)),
+                pentaxId, makerTags, unsignedLong, -1, EXV_PRINT_TAG(pentaxAFPointFocus)),
         /* Some missing ! */
         TagInfo(0x0012, "ExposureTime", N_("Exposure time"),
                 N_("Exposure time"),
-                pentaxIfdId, makerTags, unsignedLong, printPentaxExposure),
+                pentaxId, makerTags, unsignedLong, -1, printPentaxExposure),
         TagInfo(0x0013, "FNumber", N_("F-Number"),
                 N_("F-Number"),
-                pentaxIfdId, makerTags, unsignedLong, printPentaxFValue),
+                pentaxId, makerTags, unsignedLong, -1, printPentaxFValue),
         TagInfo(0x0014, "ISO", N_("ISO sensitivity"),
                 N_("ISO sensitivity settings"),
-                pentaxIfdId, makerTags, unsignedLong, EXV_PRINT_TAG(pentaxISO)),
+                pentaxId, makerTags, unsignedLong, -1, EXV_PRINT_TAG(pentaxISO)),
         /* Some missing ! */
         TagInfo(0x0016, "ExposureCompensation", N_("Exposure compensation"),
                 N_("Exposure compensation"),
-                pentaxIfdId, makerTags, unsignedLong, printPentaxCompensation),
+                pentaxId, makerTags, unsignedLong, -1, printPentaxCompensation),
         /* Some missing ! */
         TagInfo(0x0017, "MeteringMode", N_("MeteringMode"),
                 N_("MeteringMode"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxMeteringMode)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxMeteringMode)),
         TagInfo(0x0018, "AutoBracketing", N_("AutoBracketing"),
                 N_("AutoBracketing"),
-                pentaxIfdId, makerTags, undefined, printPentaxBracketing),
+                pentaxId, makerTags, undefined, -1, printPentaxBracketing),
         TagInfo(0x0019, "WhiteBallance", N_("White ballance"),
                 N_("White ballance"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxWhiteBallance)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxWhiteBallance)),
         TagInfo(0x001a, "WhiteBallanceMode", N_("White ballance mode"),
                 N_("White ballance mode"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxWhiteBallanceMode)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxWhiteBallanceMode)),
         TagInfo(0x001b, "BlueBalance", N_("Blue balance"),
                 N_("Blue color balance"),
-                pentaxIfdId, makerTags, unsignedLong, printValue),
+                pentaxId, makerTags, unsignedLong, -1, printValue),
         TagInfo(0x001c, "RedBalance", N_("Red balance"),
                 N_("Red color balance"),
-                pentaxIfdId, makerTags, unsignedLong, printValue),
+                pentaxId, makerTags, unsignedLong, -1, printValue),
         TagInfo(0x001d, "FocalLength", N_("FocalLength"),
                 N_("FocalLength"),
-                pentaxIfdId, makerTags, undefined, printPentaxFocalLength),
+                pentaxId, makerTags, undefined, -1, printPentaxFocalLength),
         TagInfo(0x001e, "DigitalZoom", N_("Digital zoom"),
                 N_("Digital zoom"),
-                pentaxIfdId, makerTags, unsignedLong, printValue),
+                pentaxId, makerTags, unsignedLong, -1, printValue),
         TagInfo(0x001f, "Saturation", N_("Saturation"),
                 N_("Saturation"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxSaturation)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxSaturation)),
         TagInfo(0x0020, "Contrast", N_("Contrast"),
                 N_("Contrast"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxContrast)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxContrast)),
         TagInfo(0x0021, "Sharpness", N_("Sharpness"),
                 N_("Sharpness"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxSharpness)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxSharpness)),
         TagInfo(0x0022, "Location", N_("Location"),
                 N_("Location"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxLocation)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxLocation)),
         TagInfo(0x0023, "Hometown", N_("Hometown"),
                 N_("Home town"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxCities)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxCities)),
         TagInfo(0x0024, "Destination", N_("Destination"),
                 N_("Destination"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxCities)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxCities)),
         TagInfo(0x0025, "HometownDST", N_("Hometown DST"),
                 N_("Whether day saving time is active in home town"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxYesNo)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxYesNo)),
         TagInfo(0x0026, "DestinationDST", N_("Destination DST"),
                 N_("Whether day saving time is active in destination"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxYesNo)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_TAG(pentaxYesNo)),
         TagInfo(0x0027, "DSPFirmwareVersion", N_("DSPFirmwareVersion"),
                 N_("DSPFirmwareVersion"),
-                pentaxIfdId, makerTags, unsignedByte, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, unsignedByte, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0028, "CPUFirmwareVersion", N_("CPUFirmwareVersion"),
                 N_("CPUFirmwareVersion"),
-                pentaxIfdId, makerTags, unsignedByte, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, unsignedByte, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0029, "FrameNumber", N_("Frame number"),
                 N_("Frame number"),
-                pentaxIfdId, makerTags, undefined, printValue),
+                pentaxId, makerTags, undefined, -1, printValue),
         /* Some missing ! */
         TagInfo(0x002d, "EffectiveLV", N_("Light value"),
                 N_("Camera calculated light value, includes exposure compensation"),
-                pentaxIfdId, makerTags, unsignedShort, printValue),
+                pentaxId, makerTags, unsignedShort, -1, printValue),
         /* Some missing ! */
         TagInfo(0x0032, "ImageProcessing", N_("Image processing"),
                 N_("Image processing"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_COMBITAG(pentaxImageProcessing, 4, 0)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_COMBITAG(pentaxImageProcessing, 4, 0)),
         TagInfo(0x0033, "PictureMode", N_("Picture mode"),
                 N_("Picture mode"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_COMBITAG(pentaxPictureMode, 3, 0)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_COMBITAG(pentaxPictureMode, 3, 0)),
         TagInfo(0x0034, "DriveMode", N_("Drive mode"),
                 N_("Drive mode"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_COMBITAG(pentaxDriveMode, 4, 0)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_COMBITAG(pentaxDriveMode, 4, 0)),
         /* Some missing ! */
         TagInfo(0x0037, "ColorSpace", N_("Color space"),
                 N_("Color space"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxColorSpace)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxColorSpace)),
         TagInfo(0x0038, "ImageAreaOffset", N_("Image area offset"),
                 N_("Image area offset"),
-                pentaxIfdId, makerTags, unsignedLong, printValue),
+                pentaxId, makerTags, unsignedLong, -1, printValue),
         TagInfo(0x0039, "RawImageSize", N_("Raw image size"),
                 N_("Raw image size"),
-                pentaxIfdId, makerTags, unsignedLong, printValue),
+                pentaxId, makerTags, unsignedLong, -1, printValue),
         /* Some missing ! */
         TagInfo(0x003e, "PreviewImageBorders", N_("Preview image borders"),
                 N_("Preview image borders"),
-                pentaxIfdId, makerTags, unsignedByte, printValue),
+                pentaxId, makerTags, unsignedByte, -1, printValue),
         TagInfo(0x003f, "LensType", N_("Lens type"),
                 N_("Lens type"),
-                pentaxIfdId, makerTags, unsignedByte, EXV_PRINT_COMBITAG_MULTI(pentaxLensType, 2, 1, 2)),
+                pentaxId, makerTags, unsignedByte, -1, EXV_PRINT_COMBITAG_MULTI(pentaxLensType, 2, 1, 2)),
         TagInfo(0x0040, "SensitivityAdjust", N_("Sensitivity adjust"),
                 N_("Sensitivity adjust"),
-                pentaxIfdId, makerTags, unsignedLong, printValue),
+                pentaxId, makerTags, unsignedLong, -1, printValue),
         TagInfo(0x0041, "DigitalFilter", N_("Digital filter"),
                 N_("Digital filter"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxOffOn)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxOffOn)),
         /* Some missing ! */
         TagInfo(0x0047, "Temperature", N_("Temperature"),
                 N_("Camera temperature"),
-                pentaxIfdId, makerTags, signedByte, printPentaxTemperature),
+                pentaxId, makerTags, signedByte, -1, printPentaxTemperature),
         TagInfo(0x0048, "AELock", N_("AE lock"),
                 N_("AE lock"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxOffOn)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxOffOn)),
         TagInfo(0x0049, "NoiseReduction", N_("Noise reduction"),
                 N_("Noise reduction"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxOffOn)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxOffOn)),
         /* Some missing ! */
         TagInfo(0x004d, "FlashExposureCompensation", N_("Flash exposure compensation"),
                 N_("Flash exposure compensation"),
-                pentaxIfdId, makerTags, signedLong, printPentaxFlashCompensation),
+                pentaxId, makerTags, signedLong, -1, printPentaxFlashCompensation),
         /* Some missing ! */
         TagInfo(0x004f, "ImageTone", N_("Image tone"),
                 N_("Image tone"),
-                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxImageTone)),
+                pentaxId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(pentaxImageTone)),
         TagInfo(0x0050, "ColorTemperature", N_("Colort temperature"),
                 N_("Colort temperature"),
-                pentaxIfdId, makerTags, unsignedShort, printValue),
+                pentaxId, makerTags, unsignedShort, -1, printValue),
         /* Some missing ! */
         TagInfo(0x005c, "ShakeReduction", N_("Shake reduction"),
                 N_("Shake reduction information"),
-                pentaxIfdId, makerTags, undefined, printValue),
+                pentaxId, makerTags, undefined, -1, printValue),
         TagInfo(0x005d, "ShutterCount", N_("Shutter count"),
                 N_("Shutter count"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: This has some encryption by date (see exiftool) */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: This has some encryption by date (see exiftool) */
         TagInfo(0x0069, "DynamicRangeExpansion", N_("Dynamic range expansion"),
                 N_("Dynamic range expansion"),
-                pentaxIfdId, makerTags, undefined, EXV_PRINT_COMBITAG(pentaxDynamicRangeExpansion, 4, 0)),
+                pentaxId, makerTags, undefined, -1, EXV_PRINT_COMBITAG(pentaxDynamicRangeExpansion, 4, 0)),
         TagInfo(0x0071, "HighISONoiseReduction", N_("High ISO noise reduction"),
                 N_("High ISO noise reduction"),
-                pentaxIfdId, makerTags, unsignedByte, EXV_PRINT_TAG(pentaxHighISONoiseReduction)),
+                pentaxId, makerTags, unsignedByte, -1, EXV_PRINT_TAG(pentaxHighISONoiseReduction)),
         TagInfo(0x0072, "AFAdjustment", N_("AF Adjustment"),
                 N_("AF Adjustment"),
-                pentaxIfdId, makerTags, undefined, printValue),
+                pentaxId, makerTags, undefined, -1, printValue),
         /* Many missing ! */
         TagInfo(0x0200, "BlackPoint", N_("Black point"),
                 N_("Black point"),
-                pentaxIfdId, makerTags, undefined, printValue),
+                pentaxId, makerTags, undefined, -1, printValue),
         TagInfo(0x0201, "WhitePoint", N_("White point"),
                 N_("White point"),
-                pentaxIfdId, makerTags, undefined, printValue),
+                pentaxId, makerTags, undefined, -1, printValue),
         /* Some missing ! */
         TagInfo(0x0205, "ShotInfo", N_("ShotInfo"),
                 N_("ShotInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0206, "AEInfo", N_("AEInfo"),
                 N_("AEInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0207, "LensInfo", N_("LensInfo"),
                 N_("LensInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0208, "FlashInfo", N_("FlashInfo"),
                 N_("FlashInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0209, "AEMeteringSegments", N_("AEMeteringSegments"),
                 N_("AEMeteringSegments"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x020a, "FlashADump", N_("FlashADump"),
                 N_("FlashADump"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x020b, "FlashBDump", N_("FlashBDump"),
                 N_("FlashBDump"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         /* Some missing ! */
         TagInfo(0x020d, "WB_RGGBLevelsDaylight", N_("WB_RGGBLevelsDaylight"),
                 N_("WB_RGGBLevelsDaylight"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x020e, "WB_RGGBLevelsShade", N_("WB_RGGBLevelsShade"),
                 N_("WB_RGGBLevelsShade"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x020f, "WB_RGGBLevelsCloudy", N_("WB_RGGBLevelsCloudy"),
                 N_("WB_RGGBLevelsCloudy"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0210, "WB_RGGBLevelsTungsten", N_("WB_RGGBLevelsTungsten"),
                 N_("WB_RGGBLevelsTungsten"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0211, "WB_RGGBLevelsFluorescentD", N_("WB_RGGBLevelsFluorescentD"),
                 N_("WB_RGGBLevelsFluorescentD"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0212, "WB_RGGBLevelsFluorescentN", N_("WB_RGGBLevelsFluorescentN"),
                 N_("WB_RGGBLevelsFluorescentN"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0213, "WB_RGGBLevelsFluorescentW", N_("WB_RGGBLevelsFluorescentW"),
                 N_("WB_RGGBLevelsFluorescentW"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0214, "WB_RGGBLevelsFlash", N_("WB_RGGBLevelsFlash"),
                 N_("WB_RGGBLevelsFlash"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0215, "CameraInfo", N_("CameraInfo"),
                 N_("CameraInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0216, "BatteryInfo", N_("BatteryInfo"),
                 N_("BatteryInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x021f, "AFInfo", N_("AFInfo"),
                 N_("AFInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0222, "ColorInfo", N_("ColorInfo"),
                 N_("ColorInfo"),
-                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
+                pentaxId, makerTags, undefined, -1, printValue), /* TODO: Decoding missing */
         TagInfo(0x0229, "SerialNumber", N_("Serial Number"),
                 N_("Serial Number"),
-                pentaxIfdId, makerTags, asciiString, printValue),
+                pentaxId, makerTags, asciiString, -1, printValue),
         // End of list marker
         TagInfo(0xffff, "(UnknownPentaxMakerNoteTag)", "(UnknownPentaxMakerNoteTag)",
                 N_("Unknown PentaxMakerNote tag"),
-                pentaxIfdId, makerTags, invalidTypeId, printValue)
+                pentaxId, makerTags, asciiString, -1, printValue)
     };
 
     const TagInfo* PentaxMakerNote::tagList()
@@ -1129,4 +1131,4 @@ namespace Exiv2 {
         return tagInfo_;
     }
 
-}                                       // namespace Exiv2
+}}                                       // namespace Internal, Exiv2
