@@ -20,14 +20,14 @@
  */
 /*
   File:    pgfimage.cpp
-  Version: $Rev: 2045 $
+  Version: $Rev: 2286 $
   Author(s): Gilles Caulier (cgilles) <caulier dot gilles at gmail dot com>
   History: 16-Jun-09, gc: submitted
   Credits: See header file
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: pgfimage.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: pgfimage.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
 
 // *****************************************************************************
 
