@@ -20,14 +20,14 @@
  */
 /*
   File:    pngchunk.cpp
-  Version: $Rev: 2045 $
+  Version: $Rev: 2344 $
   Author(s): Gilles Caulier (cgilles) <caulier dot gilles at gmail dot com>
   History: 12-Jun-06, gc: submitted
   Credits: See header file
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: pngchunk.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: pngchunk.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -276,7 +276,7 @@ namespace Exiv2 {
                 else
                 {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Exiv2::PngChunk::parseChunkContent: Failed to decode Exif metadata.\n";
+                    EXV_WARNING << "Failed to decode Exif metadata.\n";
 #endif
                     pImage->exifData().clear();
                 }
@@ -317,7 +317,7 @@ namespace Exiv2 {
                                           &iptcBlob[0],
                                           static_cast<uint32_t>(iptcBlob.size()))) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode IPTC metadata.\n";
+                    EXV_WARNING << "Failed to decode IPTC metadata.\n";
 #endif
                     pImage->clearIptcData();
                 }
@@ -327,7 +327,7 @@ namespace Exiv2 {
                                           psData.pData_,
                                           psData.size_)) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode IPTC metadata.\n";
+                    EXV_WARNING << "Failed to decode IPTC metadata.\n";
 #endif
                     pImage->clearIptcData();
                 }
@@ -351,15 +351,15 @@ namespace Exiv2 {
                 if (idx != std::string::npos && idx > 0)
                 {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Exiv2::PngChunk::parseChunkContent: Removing " << idx
-                              << " characters from the beginning of the XMP packet\n";
+                    EXV_WARNING << "Removing " << idx
+                                << " characters from the beginning of the XMP packet\n";
 #endif
                     xmpPacket = xmpPacket.substr(idx);
                 }
                 if (XmpParser::decode(pImage->xmpData(), xmpPacket))
                 {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Exiv2::PngChunk::parseChunkContent: Failed to decode XMP metadata.\n";
+                    EXV_WARNING << "Failed to decode XMP metadata.\n";
 #endif
                 }
             }
@@ -379,15 +379,15 @@ namespace Exiv2 {
                 if (idx != std::string::npos && idx > 0)
                 {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Removing " << idx << " characters "
-                              << "from the beginning of the XMP packet\n";
+                    EXV_WARNING << "Removing " << idx << " characters "
+                                << "from the beginning of the XMP packet\n";
 #endif
                     xmpPacket = xmpPacket.substr(idx);
                 }
                 if (XmpParser::decode(pImage->xmpData(), xmpPacket))
                 {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode XMP metadata.\n";
+                    EXV_WARNING << "Failed to decode XMP metadata.\n";
 #endif
                 }
             }
@@ -440,41 +440,36 @@ namespace Exiv2 {
     {
         uLongf uncompressedLen = compressedTextSize * 2; // just a starting point
         int zlibResult;
+        int dos = 0;
 
-        do
-        {
+        do {
             arr.alloc(uncompressedLen);
-            zlibResult = uncompress((Bytef*)arr.pData_, &uncompressedLen,
-                                    compressedText, compressedTextSize);
-
-            if (zlibResult == Z_OK)
-            {
-                // then it is all OK
+            zlibResult = uncompress((Bytef*)arr.pData_,
+                                    &uncompressedLen,
+                                    compressedText,
+                                    compressedTextSize);
+            if (zlibResult == Z_OK) {
                 arr.alloc(uncompressedLen);
             }
-            else if (zlibResult == Z_BUF_ERROR)
-            {
+            else if (zlibResult == Z_BUF_ERROR) {
                 // the uncompressedArray needs to be larger
-#ifdef DEBUG
-                std::cout << "Exiv2::PngChunk::parsePngChunk: doubling size for decompression.\n";
-#endif
                 uncompressedLen *= 2;
-
                 // DoS protection. can't be bigger than 64k
-                if ( uncompressedLen > 131072 )
-                    break;
+                if (uncompressedLen > 131072) {
+                    if (++dos > 1) break;
+                    uncompressedLen = 131072;
+                }
             }
-            else
-            {
+            else {
                 // something bad happened
                 throw Error(14);
             }
         }
         while (zlibResult == Z_BUF_ERROR);
 
-        if (zlibResult != Z_OK)
+        if (zlibResult != Z_OK) {
             throw Error(14);
-
+        }
     } // PngChunk::zlibUncompress
 
     std::string PngChunk::zlibCompress(const std::string& text)
