@@ -20,14 +20,14 @@
  */
 /*
   File:    pngimage.cpp
-  Version: $Rev: 2045 $
+  Version: $Rev: 2344 $
   Author(s): Gilles Caulier (cgilles) <caulier dot gilles at gmail dot com>
   History: 12-Jun-06, gc: submitted
   Credits: See header file
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: pngimage.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: pngimage.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
 
 // *****************************************************************************
 
@@ -325,7 +325,7 @@ namespace Exiv2 {
                 if (writeXmpFromPacket() == false) {
                     if (XmpParser::encode(xmpPacket_, xmpData_) > 1) {
 #ifndef SUPPRESS_WARNINGS
-                        std::cerr << "Error: Failed to encode XMP metadata.\n";
+                        EXV_ERROR << "Failed to encode XMP metadata.\n";
 #endif
                     }
                 }
