@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2009 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -23,7 +23,7 @@
   @brief   XMP property and type information.<BR>References:<BR>
   <a href="http://www.adobe.com/devnet/xmp/pdfs/xmp_specification.pdf">XMP Specification</a> from Adobe
   <I>(Property descriptions copied from the XMP specification with the permission of Adobe)</I>
-  @version $Rev: 1937 $
+  @version $Rev: 2374 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @author  Gilles Caulier (cgilles)
@@ -185,8 +185,8 @@ namespace Exiv2 {
         /*!
           @brief Register namespace \em ns with preferred prefix \em prefix.
 
-          If the namespace is a known or previously registered namespace, the
-          prefix is overwritten.
+          If the prefix is a known or previously registered prefix, the
+          corresponding namespace URI is overwritten.
 
           @note This invalidates XMP keys generated with the previous prefix.
          */
@@ -209,11 +209,15 @@ namespace Exiv2 {
           @note This invalidates XMP keys generated in any custom namespace.
          */
         static void unregisterNs();
-
-    private:
+        //! Type for the namespace registry
         typedef std::map<std::string, XmpNsInfo> NsRegistry;
+        /*!
+          @brief Get the registered namespace for a specific \em prefix from the registry.
+         */
         static const XmpNsInfo* lookupNsRegistry(const XmpNsInfo::Prefix& prefix);
-        static NsRegistry nsRegistry_;
+
+        // DATA
+        static NsRegistry nsRegistry_;          //! Namespace registry
 
     }; // class XmpProperties
 
