@@ -20,14 +20,14 @@
  */
 /*
   File:      psdimage.cpp
-  Version:   $Rev: 2092 $
+  Version:   $Rev: 2370 $
   Author(s): Marco Piovanelli, Ovolab (marco)
              Michael Ulbrich (mul)
   History:   05-Mar-2007, marco: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: psdimage.cpp 2092 2010-04-14 16:33:38Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: psdimage.cpp 2370 2010-10-25 13:24:51Z ahuggel $")
 
 //#define DEBUG 1
 
@@ -259,7 +259,7 @@ namespace Exiv2 {
                 if (io_->error() || io_->eof()) throw Error(14);
                 if (IptcParser::decode(iptcData_, rawIPTC.pData_, rawIPTC.size_)) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode IPTC metadata.\n";
+                    EXV_WARNING << "Failed to decode IPTC metadata.\n";
 #endif
                     iptcData_.clear();
                 }
@@ -275,7 +275,7 @@ namespace Exiv2 {
                 setByteOrder(bo);
                 if (rawExif.size_ > 0 && byteOrder() == invalidByteOrder) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode Exif metadata.\n";
+                    EXV_WARNING << "Failed to decode Exif metadata.\n";
 #endif
                     exifData_.clear();
                 }
@@ -290,7 +290,7 @@ namespace Exiv2 {
                 xmpPacket_.assign(reinterpret_cast<char *>(xmpPacket.pData_), xmpPacket.size_);
                 if (xmpPacket_.size() > 0 && XmpParser::decode(xmpData_, xmpPacket_)) {
 #ifndef SUPPRESS_WARNINGS
-                    std::cerr << "Warning: Failed to decode XMP metadata.\n";
+                    EXV_WARNING << "Failed to decode XMP metadata.\n";
 #endif
                 }
                 break;
@@ -419,24 +419,24 @@ namespace Exiv2 {
             uint32_t curOffset = io_->tell();
 
             // Write IPTC_NAA resource block
-            if (   resourceId == kPhotoshopResourceID_IPTC_NAA
-                || (resourceId > kPhotoshopResourceID_IPTC_NAA && iptcDone == false)) {
+            if ((resourceId == kPhotoshopResourceID_IPTC_NAA  ||
+                 resourceId >  kPhotoshopResourceID_IPTC_NAA) && iptcDone == false) {
                 newResLength += writeIptcData(iptcData_, outIo);
                 resourceSize = (resourceSize + 1) & ~1;    // adjust for padding
                 iptcDone = true;
             }
 
             // Write ExifInfo resource block
-            else if (   resourceId == kPhotoshopResourceID_ExifInfo
-                     || (resourceId > kPhotoshopResourceID_ExifInfo && exifDone == false)) {
+            else if ((resourceId == kPhotoshopResourceID_ExifInfo  ||
+                      resourceId >  kPhotoshopResourceID_ExifInfo) && exifDone == false) {
                 newResLength += writeExifData(exifData_, outIo);
                 resourceSize = (resourceSize + 1) & ~1;    // adjust for padding
                 exifDone = true;
             }
 
             // Write XMPpacket resource block
-            else if (   resourceId == kPhotoshopResourceID_XMPPacket
-                     || (resourceId > kPhotoshopResourceID_XMPPacket && xmpDone == false)) {
+            else if ((resourceId == kPhotoshopResourceID_XMPPacket  ||
+                      resourceId >  kPhotoshopResourceID_XMPPacket) && xmpDone == false) {
                 newResLength += writeXmpData(xmpData_, outIo);
                 resourceSize = (resourceSize + 1) & ~1;    // adjust for padding
                 xmpDone = true;
@@ -456,7 +456,7 @@ namespace Exiv2 {
                 us2Data(buf, resourceId, bigEndian);
                 if (outIo.write(buf, 2) != 2) throw Error(21);
                 // Write resource name as Pascal string
-                buf[0] = resourceNameLength & 0x000f;
+                buf[0] = resourceNameLength & 0x00ff;
                 if (outIo.write(buf, 1) != 1) throw Error(21);
                 buf[0] = resourceNameFirstChar;
                 if (outIo.write(buf, 1) != 1) throw Error(21);
@@ -608,7 +608,7 @@ namespace Exiv2 {
         if (writeXmpFromPacket() == false) {
             if (XmpParser::encode(xmpPacket, xmpData) > 1) {
 #ifndef SUPPRESS_WARNINGS
-                std::cerr << "Error: Failed to encode XMP metadata.\n";
+                EXV_ERROR << "Failed to encode XMP metadata.\n";
 #endif
             }
         }
