@@ -20,14 +20,14 @@
  */
 /*
   File:      rw2image.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2360 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   06-Jan-09, ahu: created
 
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: rw2image.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: rw2image.cpp 2360 2010-10-01 14:09:47Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -64,7 +64,7 @@ namespace Exiv2 {
 
     std::string Rw2Image::mimeType() const
     {
-        return "image/x-raw";
+        return "image/x-panasonic-rw2";
     }
 
     int Rw2Image::pixelWidth() const
@@ -134,7 +134,7 @@ namespace Exiv2 {
         // Todo: What if there are more preview images?
         if (list.size() > 1) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: RW2 image contains more than one preview. None used.\n";
+            EXV_WARNING << "RW2 image contains more than one preview. None used.\n";
 #endif
         }
         if (list.size() != 1) return;
@@ -143,7 +143,7 @@ namespace Exiv2 {
         Image::AutoPtr image = ImageFactory::open(preview.pData(), preview.size());
         if (image.get() == 0) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: Failed to open RW2 preview image.\n";
+            EXV_WARNING << "Failed to open RW2 preview image.\n";
 #endif
             return;
         }
@@ -152,7 +152,7 @@ namespace Exiv2 {
         if (!prevData.empty()) {
             // Filter duplicate tags
             for (ExifData::const_iterator pos = exifData_.begin(); pos != exifData_.end(); ++pos) {
-                if (pos->ifdId() == panaRawIfdId) continue;
+                if (pos->ifdId() == panaRawId) continue;
                 ExifData::iterator dup = prevData.findKey(ExifKey(pos->key()));
                 if (dup != prevData.end()) {
 #ifdef DEBUG
