@@ -20,7 +20,7 @@
  */
 /*
   File:      sigmamn.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2336 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   02-Apr-04, ahu: created
   Credits:   Sigma and Foveon MakerNote implemented according to the specification
@@ -28,13 +28,14 @@
              <http://www.x3f.info/technotes/FileDocs/MakerNoteDoc.html>
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: sigmamn.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: sigmamn.cpp 2336 2010-08-30 19:33:07Z ahuggel $")
 
 // *****************************************************************************
 // included header files
 #include "types.hpp"
-#include "sigmamn.hpp"
+#include "sigmamn_int.hpp"
+#include "tags_int.hpp"
 #include "value.hpp"
 #include "i18n.h"                // NLS support.
 
@@ -48,81 +49,83 @@ EXIV2_RCSID("@(#) $Id: sigmamn.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
 // *****************************************************************************
 // class member definitions
 namespace Exiv2 {
+    namespace Internal {
 
     // Sigma (Foveon) MakerNote Tag Info
     const TagInfo SigmaMakerNote::tagInfo_[] = {
         TagInfo(0x0002, "SerialNumber", N_("Serial Number"),
                 N_("Camera serial number"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0003, "DriveMode", N_("Drive Mode"),
                 N_("Drive mode"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0004, "ResolutionMode", N_("Resolution Mode"),
-                N_("Resolution mode"), sigmaIfdId, makerTags, asciiString, printValue),
+                N_("Resolution mode"),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0005, "AutofocusMode", N_("Autofocus Mode"),
                 N_("Autofocus mode"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0006, "FocusSetting", N_("Focus Setting"),
                 N_("Focus setting"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0007, "WhiteBalance", N_("White Balance"),
                 N_("White balance"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0008, "ExposureMode", N_("Exposure Mode"),
                 N_("Exposure mode"),
-                sigmaIfdId, makerTags, asciiString, print0x0008),
+                sigmaId, makerTags, asciiString, -1, print0x0008),
         TagInfo(0x0009, "MeteringMode", N_("Metering Mode"),
                 N_("Metering mode"),
-                sigmaIfdId, makerTags, asciiString, print0x0009),
+                sigmaId, makerTags, asciiString, -1, print0x0009),
         TagInfo(0x000a, "LensRange", N_("Lens Range"),
                 N_("Lens focal length range"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x000b, "ColorSpace", N_("Color Space"),
                 N_("Color space"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x000c, "Exposure", N_("Exposure"),
                 N_("Exposure"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x000d, "Contrast", N_("Contrast"),
                 N_("Contrast"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x000e, "Shadow", N_("Shadow"),
                 N_("Shadow"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x000f, "Highlight", N_("Highlight"),
                 N_("Highlight"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x0010, "Saturation", N_("Saturation"),
                 N_("Saturation"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x0011, "Sharpness", N_("Sharpness"),
                 N_("Sharpness"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x0012, "FillLight", N_("Fill Light"),
                 N_("X3 Fill light"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x0014, "ColorAdjustment", N_("Color Adjustment"),
                 N_("Color adjustment"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x0015, "AdjustmentMode", N_("Adjustment Mode"),
                 N_("Adjustment mode"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0016, "Quality", N_("Quality"),
                 N_("Quality"),
-                sigmaIfdId, makerTags, asciiString, printStripLabel),
+                sigmaId, makerTags, asciiString, -1, printStripLabel),
         TagInfo(0x0017, "Firmware", N_("Firmware"),
                 N_("Firmware"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0018, "Software", N_("Software"),
                 N_("Software"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0019, "AutoBracket", N_("Auto Bracket"),
                 N_("Auto bracket"),
-                sigmaIfdId, makerTags, asciiString, printValue),
+                sigmaId, makerTags, asciiString, -1, printValue),
         // End of list marker
         TagInfo(0xffff, "(UnknownSigmaMakerNoteTag)", "(UnknownSigmaMakerNoteTag)",
                 N_("Unknown SigmaMakerNote tag"),
-                sigmaIfdId, makerTags, invalidTypeId, printValue)
+                sigmaId, makerTags, asciiString, -1, printValue)
     };
 
     const TagInfo* SigmaMakerNote::tagList()
@@ -170,4 +173,4 @@ namespace Exiv2 {
         return os;
     }
 
-}                                       // namespace Exiv2
+}}                                      // namespace Internal, Exiv2
