@@ -20,14 +20,14 @@
  */
 /*
   File:      types.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2329 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: types.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: types.cpp 2329 2010-08-24 15:54:05Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -152,8 +152,10 @@ namespace Exiv2 {
     {
         if (size > size_) {
             delete[] pData_;
-            size_ = size;
+            pData_ = 0;
+            size_ = 0;
             pData_ = new byte[size];
+            size_ = size;
         }
     }
 
@@ -177,6 +179,38 @@ namespace Exiv2 {
     // *************************************************************************
     // free functions
 
+    std::ostream& operator<<(std::ostream& os, const Rational& r)
+    {
+        return os << r.first << "/" << r.second;
+    }
+
+    std::istream& operator>>(std::istream& is, Rational& r)
+    {
+        int32_t nominator;
+        int32_t denominator;
+        char c('\0');
+        is >> nominator >> c >> denominator;
+        if (c != '/') is.setstate(std::ios::failbit);
+        if (is) r = std::make_pair(nominator, denominator);
+        return is;
+    }
+
+    std::ostream& operator<<(std::ostream& os, const URational& r)
+    {
+        return os << r.first << "/" << r.second;
+    }
+
+    std::istream& operator>>(std::istream& is, URational& r)
+    {
+        uint32_t nominator;
+        uint32_t denominator;
+        char c('\0');
+        is >> nominator >> c >> denominator;
+        if (c != '/') is.setstate(std::ios::failbit);
+        if (is) r = std::make_pair(nominator, denominator);
+        return is;
+    }
+
     uint16_t getUShort(const byte* buf, ByteOrder byteOrder)
     {
         if (byteOrder == littleEndian) {
@@ -235,6 +269,54 @@ namespace Exiv2 {
         return std::make_pair(nominator, denominator);
     }
 
+    float getFloat(const byte* buf, ByteOrder byteOrder)
+    {
+        // This algorithm assumes that the internal representation of the float
+        // type is the 4-byte IEEE 754 binary32 format, which is common but not
+        // required by the C++ standard.
+        assert(sizeof(float) == 4);
+        union {
+            uint32_t ul_;
+            float    f_;
+        } u;
+        u.ul_ = getULong(buf, byteOrder);
+        return u.f_;
+    }
+
+    double getDouble(const byte* buf, ByteOrder byteOrder)
+    {
+        // This algorithm assumes that the internal representation of the double
+        // type is the 8-byte IEEE 754 binary64 format, which is common but not
+        // required by the C++ standard.
+        assert(sizeof(double) == 8);
+        union {
+            uint64_t ull_;
+            double   d_;
+        } u;
+        u.ull_ = 0;
+        if (byteOrder == littleEndian) {
+            u.ull_ =   static_cast<uint64_t>(buf[7]) << 56
+                     | static_cast<uint64_t>(buf[6]) << 48
+                     | static_cast<uint64_t>(buf[5]) << 40
+                     | static_cast<uint64_t>(buf[4]) << 32
+                     | static_cast<uint64_t>(buf[3]) << 24
+                     | static_cast<uint64_t>(buf[2]) << 16
+                     | static_cast<uint64_t>(buf[1]) <<  8
+                     | static_cast<uint64_t>(buf[0]);
+        }
+        else {
+            u.ull_ =   static_cast<uint64_t>(buf[0]) << 56
+                     | static_cast<uint64_t>(buf[1]) << 48
+                     | static_cast<uint64_t>(buf[2]) << 40
+                     | static_cast<uint64_t>(buf[3]) << 32
+                     | static_cast<uint64_t>(buf[4]) << 24
+                     | static_cast<uint64_t>(buf[5]) << 16
+                     | static_cast<uint64_t>(buf[6]) <<  8
+                     | static_cast<uint64_t>(buf[7]);
+        }
+        return u.d_;
+    }
+
     long us2Data(byte* buf, uint16_t s, ByteOrder byteOrder)
     {
         if (byteOrder == littleEndian) {
@@ -309,6 +391,55 @@ namespace Exiv2 {
         return o;
     }
 
+    long f2Data(byte* buf, float f, ByteOrder byteOrder)
+    {
+        // This algorithm assumes that the internal representation of the float
+        // type is the 4-byte IEEE 754 binary32 format, which is common but not
+        // required by the C++ standard.
+        assert(sizeof(float) == 4);
+        union {
+            uint32_t ul_;
+            float    f_;
+        } u;
+        u.f_ = f;
+        return ul2Data(buf, u.ul_, byteOrder);
+    }
+
+    long d2Data(byte* buf, double d, ByteOrder byteOrder)
+    {
+        // This algorithm assumes that the internal representation of the double
+        // type is the 8-byte IEEE 754 binary64 format, which is common but not
+        // required by the C++ standard.
+        assert(sizeof(double) == 8);
+        union {
+            uint64_t ull_;
+            double   d_;
+        } u;
+        u.d_ = d;
+        uint64_t m = 0xff;
+        if (byteOrder == littleEndian) {
+            buf[0] =  (byte)(u.ull_ & m);
+            buf[1] = (byte)((u.ull_ & (m <<  8)) >>  8);
+            buf[2] = (byte)((u.ull_ & (m << 16)) >> 16);
+            buf[3] = (byte)((u.ull_ & (m << 24)) >> 24);
+            buf[4] = (byte)((u.ull_ & (m << 32)) >> 32);
+            buf[5] = (byte)((u.ull_ & (m << 40)) >> 40);
+            buf[6] = (byte)((u.ull_ & (m << 48)) >> 48);
+            buf[7] = (byte)((u.ull_ & (m << 56)) >> 56);
+        }
+        else {
+            buf[0] = (byte)((u.ull_ & (m << 56)) >> 56);
+            buf[1] = (byte)((u.ull_ & (m << 48)) >> 48);
+            buf[2] = (byte)((u.ull_ & (m << 40)) >> 40);
+            buf[3] = (byte)((u.ull_ & (m << 32)) >> 32);
+            buf[4] = (byte)((u.ull_ & (m << 24)) >> 24);
+            buf[5] = (byte)((u.ull_ & (m << 16)) >> 16);
+            buf[6] = (byte)((u.ull_ & (m <<  8)) >>  8);
+            buf[7] =  (byte)(u.ull_ & m);
+        }
+        return 8;
+    }
+
     void hexdump(std::ostream& os, const byte* buf, long len, long offset)
     {
         const std::string::size_type pos = 8 + 16 * 3 + 2;
