@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2009 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,11 +21,11 @@
 /*!
   @file    types.hpp
   @brief   Type definitions for %Exiv2 and related functionality
-  @version $Rev: 1983 $
+  @version $Rev: 2340 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created<BR>
-           11-Feb-04, ahu: isolated as a component
+           11-Feb-04, ahu: isolated as a component<BR>
            31-Jul-04, brad: added Time, Data and String values
  */
 #ifndef TYPES_HPP_
@@ -62,8 +62,11 @@
 typedef unsigned __int8  uint8_t;
 typedef unsigned __int16 uint16_t;
 typedef unsigned __int32 uint32_t;
+typedef unsigned __int64 uint64_t;
+typedef __int8           int8_t;
 typedef __int16          int16_t;
 typedef __int32          int32_t;
+typedef __int64          int64_t;
 #endif
 
 /*!
@@ -144,84 +147,6 @@ namespace Exiv2 {
         lastTypeId    =0x1ffff  //!< Last type id.
     };
 
-    //! Type to specify the IFD to which a metadata belongs
-    enum IfdId {
-        ifdIdNotSet,
-        ifd0Id,
-        exifIfdId,
-        gpsIfdId,
-        iopIfdId,
-        ifd1Id,
-        ifd2Id,
-        ifd3Id,
-        subImage1Id,
-        subImage2Id,
-        subImage3Id,
-        subImage4Id,
-        mnIfdId,
-        canonIfdId,
-        canonCsIfdId,
-        canonSiIfdId,
-        canonCfIfdId,
-        canonPiIfdId,
-        canonPaIfdId,
-        canonFiIfdId,
-        fujiIfdId,
-        minoltaIfdId,
-        minoltaCs5DIfdId,
-        minoltaCs7DIfdId,
-        minoltaCsOldIfdId,
-        minoltaCsNewIfdId,
-        nikon1IfdId,
-        nikon2IfdId,
-        nikon3IfdId,
-        nikonPvIfdId,
-        nikonVrIfdId,
-        nikonPcIfdId,
-        nikonWtIfdId,
-        nikonIiIfdId,
-        nikonAfIfdId,
-        nikonSi1IfdId,
-        nikonSi2IfdId,
-        nikonSi3IfdId,
-        nikonSi4IfdId,
-        nikonSi5IfdId,
-        nikonSi6IfdId,
-        nikonLd1IfdId,
-        nikonLd2IfdId,
-        nikonLd3IfdId,
-        nikonCb1IfdId,
-        nikonCb2IfdId,
-        nikonCb2aIfdId,
-        nikonCb2bIfdId,
-        nikonCb3IfdId,
-        nikonCb4IfdId,
-        olympusIfdId,
-        olympus2IfdId,
-        olympusCsIfdId,
-        olympusEqIfdId,
-        olympusRdIfdId,
-        olympusRd2IfdId,
-        olympusIpIfdId,
-        olympusFiIfdId,
-        olympusFe1IfdId,
-        olympusFe2IfdId,
-        olympusFe3IfdId,
-        olympusFe4IfdId,
-        olympusFe5IfdId,
-        olympusFe6IfdId,
-        olympusFe7IfdId,
-        olympusFe8IfdId,
-        olympusFe9IfdId,
-        olympusRiIfdId,
-        panasonicIfdId,
-        panaRawIfdId,
-        pentaxIfdId,
-        sigmaIfdId,
-        sonyIfdId,
-        lastIfdId
-    };
-
     //! Container for binary data
     typedef std::vector<byte> Blob;
 
@@ -345,6 +270,10 @@ namespace Exiv2 {
     EXIV2API int32_t getLong(const byte* buf, ByteOrder byteOrder);
     //! Read an 8 byte signed rational value from the data buffer
     EXIV2API Rational getRational(const byte* buf, ByteOrder byteOrder);
+    //! Read a 4 byte single precision floating point value (IEEE 754 binary32) from the data buffer
+    EXIV2API float getFloat(const byte* buf, ByteOrder byteOrder);
+    //! Read an 8 byte double precision floating point value (IEEE 754 binary64) from the data buffer
+    EXIV2API double getDouble(const byte* buf, ByteOrder byteOrder);
 
     //! Output operator for our fake rational
     EXIV2API std::ostream& operator<<(std::ostream& os, const Rational& r);
@@ -385,6 +314,16 @@ namespace Exiv2 {
              return number of bytes written.
      */
     EXIV2API long r2Data(byte* buf, Rational l, ByteOrder byteOrder);
+    /*!
+      @brief Convert a single precision floating point (IEEE 754 binary32) float
+             to data, write the data to the buffer, return number of bytes written.
+     */
+    EXIV2API long f2Data(byte* buf, float f, ByteOrder byteOrder);
+    /*!
+      @brief Convert a double precision floating point (IEEE 754 binary64) double
+             to data, write the data to the buffer, return number of bytes written.
+     */
+    EXIV2API long d2Data(byte* buf, double d, ByteOrder byteOrder);
 
     /*!
       @brief Print len bytes from buf in hex and ASCII format to the given
