@@ -20,13 +20,13 @@
  */
 /*
   File:      utils.cpp
-  Version:   $Rev: 2045 $
+  Version:   $Rev: 2286 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: utils.cpp 2045 2010-04-03 07:53:30Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: utils.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
 
 // *****************************************************************************
 // included header files
