@@ -20,15 +20,15 @@
  */
 /*
   File:      value.cpp
-  Version:   $Rev: 2090 $
+  Version:   $Rev: 2344 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
              31-Jul-04, brad: added Time, Date and String values
  */
 // *****************************************************************************
-#include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: value.cpp 2090 2010-04-14 16:17:55Z ahuggel $")
+#include "rcsid_int.hpp"
+EXIV2_RCSID("@(#) $Id: value.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -76,8 +76,6 @@ namespace Exiv2 {
         case invalidTypeId:
         case signedByte:
         case unsignedByte:
-        case tiffFloat:
-        case tiffDouble:
             value = AutoPtr(new DataValue(typeId));
             break;
         case asciiString:
@@ -88,7 +86,7 @@ namespace Exiv2 {
             break;
         case unsignedLong:
         case tiffIfd:
-            value = AutoPtr(new ValueType<uint32_t>);
+            value = AutoPtr(new ValueType<uint32_t>(typeId));
             break;
         case unsignedRational:
             value = AutoPtr(new ValueType<URational>);
@@ -105,6 +103,12 @@ namespace Exiv2 {
         case signedRational:
             value = AutoPtr(new ValueType<Rational>);
             break;
+        case tiffFloat:
+            value = AutoPtr(new ValueType<float>);
+            break;
+        case tiffDouble:
+            value = AutoPtr(new ValueType<double>);
+            break;
         case string:
             value = AutoPtr(new StringValue);
             break;
@@ -469,7 +473,7 @@ namespace Exiv2 {
             charsetId = CharsetInfo::charsetIdByName(name);
             if (charsetId == invalidCharsetId) {
 #ifndef SUPPRESS_WARNINGS
-                std::cerr << "Warning: " << Error(28, name) << "\n";
+                EXV_WARNING << Error(28, name) << "\n";
 #endif
                 return 1;
             }
@@ -921,7 +925,7 @@ namespace Exiv2 {
         // Hard coded to read Iptc style dates
         if (len != 8) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: " << Error(29) << "\n";
+            EXV_WARNING << Error(29) << "\n";
 #endif
             return 1;
         }
@@ -932,7 +936,7 @@ namespace Exiv2 {
                              &date_.year, &date_.month, &date_.day);
         if (scanned != 3) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: " << Error(29) << "\n";
+            EXV_WARNING << Error(29) << "\n";
 #endif
             return 1;
         }
@@ -944,7 +948,7 @@ namespace Exiv2 {
         // Hard coded to read Iptc style dates
         if (buf.length() < 8) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: " << Error(29) << "\n";
+            EXV_WARNING << Error(29) << "\n";
 #endif
             return 1;
         }
@@ -952,7 +956,7 @@ namespace Exiv2 {
                              &date_.year, &date_.month, &date_.day);
         if (scanned != 3) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: " << Error(29) << "\n";
+            EXV_WARNING << Error(29) << "\n";
 #endif
             return 1;
         }
@@ -1067,7 +1071,7 @@ namespace Exiv2 {
         if (rc) {
             rc = 1;
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: " << Error(30) << "\n";
+            EXV_WARNING << Error(30) << "\n";
 #endif
         }
         return rc;
@@ -1087,7 +1091,7 @@ namespace Exiv2 {
         if (rc) {
             rc = 1;
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: " << Error(30) << "\n";
+            EXV_WARNING << Error(30) << "\n";
 #endif
         }
         return rc;
