@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2009 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,7 +21,7 @@
 /*!
   @file    value.hpp
   @brief   Value interface and concrete subclasses
-  @version $Rev: 1937 $
+  @version $Rev: 2306 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created
@@ -40,6 +40,7 @@
 #include <vector>
 #include <map>
 #include <iostream>
+#include <iomanip>
 #include <sstream>
 #include <memory>
 #include <cstring>
@@ -217,8 +218,8 @@ namespace Exiv2 {
           <TR><TD class="indexkey">signedShort</TD><TD class="indexvalue">%ValueType &lt; int16_t &gt;</TD></TR>
           <TR><TD class="indexkey">signedLong</TD><TD class="indexvalue">%ValueType &lt; int32_t &gt;</TD></TR>
           <TR><TD class="indexkey">signedRational</TD><TD class="indexvalue">%ValueType &lt; Rational &gt;</TD></TR>
-          <TR><TD class="indexkey">tiffFloat</TD><TD class="indexvalue">%DataValue(tiffFloat)</TD></TR>
-          <TR><TD class="indexkey">tiffDouble</TD><TD class="indexvalue">%DataValue(tiffDouble)</TD></TR>
+          <TR><TD class="indexkey">tiffFloat</TD><TD class="indexvalue">%ValueType &lt; float &gt;</TD></TR>
+          <TR><TD class="indexkey">tiffDouble</TD><TD class="indexvalue">%ValueType &lt; double &gt;</TD></TR>
           <TR><TD class="indexkey">tiffIfd</TD><TD class="indexvalue">%ValueType &lt; uint32_t &gt;</TD></TR>
           <TR><TD class="indexkey">date</TD><TD class="indexvalue">%DateValue</TD></TR>
           <TR><TD class="indexkey">time</TD><TD class="indexvalue">%TimeValue</TD></TR>
@@ -529,7 +530,7 @@ namespace Exiv2 {
             const char* code_;                      //!< Code of the charset
         }; // struct CharsetTable
         //! Charset information lookup functions. Implemented as a static class.
-        class CharsetInfo {
+        class EXIV2API CharsetInfo {
             //! Prevent construction: not implemented.
             CharsetInfo() {}
             //! Prevent copy-construction: not implemented.
@@ -566,7 +567,6 @@ namespace Exiv2 {
 
         //! @name Manipulators
         //@{
-        using StringValueBase::read;
         /*!
           @brief Read the value from a comment
 
@@ -580,19 +580,47 @@ namespace Exiv2 {
                   1 if an invalid character set is encountered
         */
         int read(const std::string& comment);
+        /*!
+          @brief Read the comment from a byte buffer.
+         */
+        int read(const byte* buf, long len, ByteOrder byteOrder);
         //@}
 
         //! @name Accessors
         //@{
         AutoPtr clone() const { return AutoPtr(clone_()); }
+        long copy(byte* buf, ByteOrder byteOrder) const;
         /*!
           @brief Write the comment in a format which can be read by
           read(const std::string& comment).
          */
         std::ostream& write(std::ostream& os) const;
-        //! Return the comment (without a charset="..." prefix)
-        std::string comment() const;
-        //! Return the charset id of the comment
+        /*!
+          @brief Return the comment (without a charset="..." prefix)
+
+          The comment is decoded to UTF-8. For Exif UNICODE comments, the
+          function makes an attempt to correctly determine the character
+          encoding of the value. Alternatively, the optional \em encoding
+          parameter can be used to specify it.
+
+          @param encoding Optional argument to specify the character encoding
+              that the comment is encoded in, as an iconv(3) name. Only used
+              for Exif UNICODE comments.
+
+          @return A string containing the comment converted to UTF-8.
+         */
+        std::string comment(const char* encoding =0) const;
+        /*!
+          @brief Determine the character encoding that was used to encode the
+              UNICODE comment value as an iconv(3) name.
+
+          If the comment \em c starts with a BOM, the BOM is interpreted and
+          removed from the string.
+
+          Todo: Implement rules to guess if the comment is UTF-8 encoded.
+         */
+        const char* detectCharset(std::string& c) const;
+        //! Return the Exif charset id of the comment
         CharsetId charsetId() const;
         //@}
 
@@ -600,6 +628,10 @@ namespace Exiv2 {
         //! Internal virtual copy constructor.
         EXV_DLLLOCAL virtual CommentValue* clone_() const;
 
+    public:
+        // DATA
+        ByteOrder byteOrder_;      //!< Byte order of the comment string that was read
+
     }; // class CommentValue
 
     /*!
@@ -1178,6 +1210,10 @@ namespace Exiv2 {
     template<> inline TypeId getType<int32_t>() { return signedLong; }
     //! Specialization for a signed rational
     template<> inline TypeId getType<Rational>() { return signedRational; }
+    //! Specialization for a float
+    template<> inline TypeId getType<float>() { return tiffFloat; }
+    //! Specialization for a double
+    template<> inline TypeId getType<double>() { return tiffDouble; }
 
     // No default implementation: let the compiler/linker complain
     // template<typename T> inline TypeId getType() { return invalid; }
@@ -1194,12 +1230,12 @@ namespace Exiv2 {
 
         //! @name Creators
         //@{
-        //! Default constructor.
-        ValueType();
-        //! Constructor
-        ValueType(const byte* buf, long len, ByteOrder byteOrder);
-        //! Constructor (Note: Argument \em byteOrder is ignored and deprecated)
-        explicit ValueType(const T& val, ByteOrder byteOrder =littleEndian);
+        //! Default Constructor.
+        explicit ValueType(TypeId typeId =getType<T>());
+        //! Constructor.
+        ValueType(const byte* buf, long len, ByteOrder byteOrder, TypeId typeId =getType<T>());
+        //! Constructor.
+        explicit ValueType(const T& val, TypeId typeId =getType<T>());
         //! Copy constructor
         ValueType(const ValueType<T>& rhs);
         //! Virtual destructor.
@@ -1290,6 +1326,10 @@ namespace Exiv2 {
     typedef ValueType<int32_t> LongValue;
     //! Signed rational value type
     typedef ValueType<Rational> RationalValue;
+    //! Float value type
+    typedef ValueType<float> FloatValue;
+    //! Double value type
+    typedef ValueType<double> DoubleValue;
 
 // *****************************************************************************
 // free functions, template and inline definitions
@@ -1342,6 +1382,18 @@ namespace Exiv2 {
     {
         return getRational(buf, byteOrder);
     }
+    // Specialization for a 4 byte float value.
+    template<>
+    inline float getValue(const byte* buf, ByteOrder byteOrder)
+    {
+        return getFloat(buf, byteOrder);
+    }
+    // Specialization for a 8 byte double value.
+    template<>
+    inline double getValue(const byte* buf, ByteOrder byteOrder)
+    {
+        return getDouble(buf, byteOrder);
+    }
 
     /*!
       @brief Convert a value of type T to data, write the data to the data buffer.
@@ -1410,23 +1462,41 @@ namespace Exiv2 {
     {
         return r2Data(buf, t, byteOrder);
     }
+    /*!
+      @brief Specialization to write a float to the data buffer.
+             Return the number of bytes written.
+     */
+    template<>
+    inline long toData(byte* buf, float t, ByteOrder byteOrder)
+    {
+        return f2Data(buf, t, byteOrder);
+    }
+    /*!
+      @brief Specialization to write a double to the data buffer.
+             Return the number of bytes written.
+     */
+    template<>
+    inline long toData(byte* buf, double t, ByteOrder byteOrder)
+    {
+        return d2Data(buf, t, byteOrder);
+    }
 
     template<typename T>
-    ValueType<T>::ValueType()
-        : Value(getType<T>()), pDataArea_(0), sizeDataArea_(0)
+    ValueType<T>::ValueType(TypeId typeId)
+        : Value(typeId), pDataArea_(0), sizeDataArea_(0)
     {
     }
 
     template<typename T>
-    ValueType<T>::ValueType(const byte* buf, long len, ByteOrder byteOrder)
-        : Value(getType<T>()), pDataArea_(0), sizeDataArea_(0)
+    ValueType<T>::ValueType(const byte* buf, long len, ByteOrder byteOrder, TypeId typeId)
+        : Value(typeId), pDataArea_(0), sizeDataArea_(0)
     {
         read(buf, len, byteOrder);
     }
 
     template<typename T>
-    ValueType<T>::ValueType(const T& val, ByteOrder /*byteOrder*/)
-        : Value(getType<T>()), pDataArea_(0), sizeDataArea_(0)
+    ValueType<T>::ValueType(const T& val, TypeId typeId)
+        : Value(typeId), pDataArea_(0), sizeDataArea_(0)
     {
         value_.push_back(val);
     }
@@ -1484,12 +1554,13 @@ namespace Exiv2 {
     {
         std::istringstream is(buf);
         T tmp;
-        value_.clear();
+        ValueList val;
         while (!(is.eof())) {
             is >> tmp;
             if (is.fail()) return 1;
-            value_.push_back(tmp);
+            val.push_back(tmp);
         }
+        value_.swap(val);
         return 0;
     }
 
@@ -1528,7 +1599,7 @@ namespace Exiv2 {
         typename ValueList::const_iterator end = value_.end();
         typename ValueList::const_iterator i = value_.begin();
         while (i != end) {
-            os << *i;
+            os << std::setprecision(15) << *i;
             if (++i != end) os << " ";
         }
         return os;
@@ -1546,7 +1617,7 @@ namespace Exiv2 {
     long ValueType<T>::toLong(long n) const
     {
         ok_ = true;
-        return value_[n];
+        return static_cast<long>(value_[n]);
     }
     // Specialization for rational
     template<>
@@ -1608,6 +1679,22 @@ namespace Exiv2 {
         ok_ = true;
         return Rational(value_[n].first, value_[n].second);
     }
+    // Specialization for float.
+    template<>
+    inline Rational ValueType<float>::toRational(long n) const
+    {
+        ok_ = true;
+        // Warning: This is a very simple conversion, see floatToRationalCast()
+        return floatToRationalCast(value_[n]);
+    }
+    // Specialization for double.
+    template<>
+    inline Rational ValueType<double>::toRational(long n) const
+    {
+        ok_ = true;
+        // Warning: This is a very simple conversion, see floatToRationalCast()
+        return floatToRationalCast(static_cast<float>(value_[n]));
+    }
 
     template<typename T>
     long ValueType<T>::sizeDataArea() const
