@@ -21,7 +21,7 @@
 /*!
   @file    xmpsidecar.hpp
   @brief   An Image subclass to support XMP sidecar files
-  @version $Rev: 2045 $
+  @version $Rev: 2372 $
   @author  Andreas Huggel
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    07-Mar-08, ahu: created
@@ -98,10 +98,6 @@ namespace Exiv2 {
         XmpSidecar& operator=(const XmpSidecar& rhs);
         //@}
 
-        // DATA
-        static const char* xmlHeader_;
-        static const long  xmlHdrCnt_;
-
     }; // class XmpSidecar
 
 // *****************************************************************************
